@@ -31,9 +31,11 @@
 #include <QIODevice>
 #include <QCommandLineParser>
 #include "pappsomspp/core/processing/uimonitor/uimonitortext.h"
+#include "pappsomspp/core/processing/uimonitor/uimonitorvoid.h"
 #include "pappsomspp/core/processing/cbor/mzcbor/mzmlconvert.h"
 #include "pappsomspp/core/pappsoexception.h"
 #include <QDateTime>
+#include <QDir>
 #include <QFile>
 #include <QFileInfo>
 #include <QTimer>
@@ -81,13 +83,15 @@ Mzml2MzcborCli::run()
 
       QCommandLineOption mzmlInputOption(
         QStringList() << "i" << "input",
-        QCoreApplication::translate("mzML file",
-                                    "PSI mzML file <mzML> or use '-' to read data from stdin."),
+        QCoreApplication::translate("mzML file or directory",
+                                    "PSI mzML file <mzML> or directory path containing <dir> "
+                                    "containing mzML files or use '-' to read data from stdin."),
         QCoreApplication::translate("mzML", "mzML"));
 
       QCommandLineOption mzcborOutputOption(
         QStringList() << "o" << "output",
-        QCoreApplication::translate("mzCBOR", "path to the mzCBOR output file <mzcbor>."),
+        QCoreApplication::translate("mzCBOR file or directory",
+                                    "path to the mzCBOR output file <mzcbor> or output directory."),
         QCoreApplication::translate("mzcbor", "mzcbor"));
 
 
@@ -114,7 +118,7 @@ Mzml2MzcborCli::run()
 
 
       // PsmProcess cbor_psm_process(json_parameters);
-
+      bool is_dir = false;
       QFile input_mzml_file;
       if(!parser.isSet(mzmlInputOption))
         {
@@ -130,64 +134,85 @@ Mzml2MzcborCli::run()
         }
       else
         {
-          input_mzml_file.setFileName(parser.value(mzmlInputOption));
-          if(!input_mzml_file.open(QIODevice::ReadOnly))
+          QFileInfo input_mzml_fileinfo(parser.value(mzmlInputOption));
+          if(input_mzml_fileinfo.isFile())
             {
-              throw pappso::PappsoException(QObject::tr("Unable to open mzML file '%1' :\n%2\n")
-                                              .arg(QFileInfo(input_mzml_file).absoluteFilePath())
-                                              .arg(input_mzml_file.errorString()));
+              qDebug();
+              input_mzml_file.setFileName(input_mzml_fileinfo.absoluteFilePath());
+              if(!input_mzml_file.open(QIODevice::ReadOnly))
+                {
+                  throw pappso::PappsoException(
+                    QObject::tr("Unable to open mzML file '%1' :\n%2\n")
+                      .arg(QFileInfo(input_mzml_file).absoluteFilePath())
+                      .arg(input_mzml_file.errorString()));
+                }
+            }
+          else if(input_mzml_fileinfo.isDir())
+            {
+              qDebug();
+              is_dir = true;
+              convertAllMzmlInDir(monitor,
+                                  input_mzml_fileinfo,
+                                  parser.value(mzcborOutputOption),
+                                  parser.isSet(writeIndex));
             }
         }
 
-      QFile mzcbor_file;
-      pappso::cbor::CborStreamWriter *p_cborWriter = nullptr;
-      QString mzcbor_index_filename;
-      if(parser.isSet(mzcborOutputOption))
+      if(is_dir)
         {
-          QString mzcbor_filename = parser.value(mzcborOutputOption);
-          if(!mzcbor_filename.isEmpty())
-            {
-              mzcbor_file.setFileName(mzcbor_filename);
-              mzcbor_file.open(QIODevice::WriteOnly);
-              p_cborWriter          = new pappso::cbor::CborStreamWriter(&mzcbor_file);
-              mzcbor_index_filename = mzcbor_filename.append(".idx");
-            }
         }
       else
         {
-          mzcbor_file.open(stdout, QIODevice::WriteOnly);
-          p_cborWriter = new pappso::cbor::CborStreamWriter(&mzcbor_file);
-        }
-
-
-      if(p_cborWriter != nullptr)
-        {
-          pappso::cbor::mzcbor::MzmlConvert mzml_convert(&monitor, p_cborWriter);
-
-          mzml_convert.read(&input_mzml_file);
-          input_mzml_file.close();
-          mzcbor_file.close();
-          if(!mzml_convert.errorString().isEmpty())
+          QFile mzcbor_file;
+          pappso::cbor::CborStreamWriter *p_cborWriter = nullptr;
+          QString mzcbor_index_filename;
+          if(parser.isSet(mzcborOutputOption))
             {
-              throw pappso::PappsoException(QObject::tr("ERROR converting mzML to mzCBOR :\n%1")
-                                              .arg(mzml_convert.errorString()));
+              QString mzcbor_filename = parser.value(mzcborOutputOption);
+              if(!mzcbor_filename.isEmpty())
+                {
+                  mzcbor_file.setFileName(mzcbor_filename);
+                  mzcbor_file.open(QIODevice::WriteOnly);
+                  p_cborWriter          = new pappso::cbor::CborStreamWriter(&mzcbor_file);
+                  mzcbor_index_filename = mzcbor_filename.append(".idx");
+                }
+            }
+          else
+            {
+              mzcbor_file.open(stdout, QIODevice::WriteOnly);
+              p_cborWriter = new pappso::cbor::CborStreamWriter(&mzcbor_file);
             }
 
-          if(!mzcbor_index_filename.isEmpty() && parser.isSet(writeIndex))
-            {
 
-              QFile mzcbor_index_file;
-              mzcbor_index_file.setFileName(mzcbor_index_filename);
-              mzcbor_index_file.open(QIODevice::WriteOnly);
-              pappso::cbor::CborStreamWriter *index_writer =
-                new pappso::cbor::CborStreamWriter(&mzcbor_index_file);
-                mzml_convert.writeMzcborIndex(index_writer);
-                mzcbor_index_file.close();
-                
+          if(p_cborWriter != nullptr)
+            {
+              pappso::cbor::mzcbor::MzmlConvert mzml_convert(&monitor, p_cborWriter);
+
+              mzml_convert.read(&input_mzml_file);
+              input_mzml_file.close();
+              mzcbor_file.close();
+              if(!mzml_convert.errorString().isEmpty())
+                {
+                  throw pappso::PappsoException(QObject::tr("ERROR converting mzML to mzCBOR :\n%1")
+                                                  .arg(mzml_convert.errorString()));
+                }
+
+              if(!mzcbor_index_filename.isEmpty() && parser.isSet(writeIndex))
+                {
+
+                  QFile mzcbor_index_file;
+                  mzcbor_index_file.setFileName(mzcbor_index_filename);
+                  mzcbor_index_file.open(QIODevice::WriteOnly);
+                  pappso::cbor::CborStreamWriter *index_writer =
+                    new pappso::cbor::CborStreamWriter(&mzcbor_index_file);
+                  mzml_convert.writeMzcborIndex(index_writer);
+                  mzcbor_index_file.close();
+                  delete index_writer;
+                }
+              delete p_cborWriter;
             }
         }
 
-
       qDebug();
     }
   catch(pappso::PappsoException &error)
@@ -244,6 +269,93 @@ Mzml2MzcborCli::aboutToQuitApp()
   // delete any objects
 }
 
+void
+Mzml2MzcborCli::convertAllMzmlInDir(pappso::UiMonitorInterface &monitor,
+                                    const QFileInfo &input_dir,
+                                    const QString &output_str,
+                                    bool write_index)
+{
+  qDebug();
+  QStringList mzml_file_list;
+  QDir dir(input_dir.absoluteDir());
+  dir.setFilter(QDir::Files);
+  foreach(QFileInfo fileInfo, dir.entryInfoList(QDir::Files))
+    {
+
+      qDebug() << fileInfo.suffix().toLower();
+      if(fileInfo.isFile() && (fileInfo.suffix().toLower() == "mzml"))
+        {
+          mzml_file_list << fileInfo.absoluteFilePath();
+        }
+    }
+  QDir output_dir(dir);
+  if(!output_str.isEmpty())
+    {
+      output_dir.setPath(QFileInfo(output_str).absoluteDir().absolutePath());
+    }
+  if(!output_dir.exists())
+    {
+
+      throw pappso::PappsoException(QObject::tr("ERROR the output directory does not exists :\n%1")
+                                      .arg(output_dir.absolutePath()));
+    }
+
+  for(QString &input_file_name : mzml_file_list)
+    {
+      QString output_file_name =
+        output_dir.absoluteFilePath(QFileInfo(input_file_name).baseName().append(".mzcbor"));
+      qDebug() << output_file_name;
+      qDebug() << input_file_name;
+
+      monitor.setStatus(
+        QObject::tr("Converting %1 to %2").arg(input_file_name).arg(output_file_name));
+      QFile input_file(input_file_name);
+      if(input_file.open(QIODevice::ReadOnly))
+        {
+
+          QFile mzcbor_file;
+          mzcbor_file.setFileName(output_file_name);
+          if(mzcbor_file.open(QIODevice::WriteOnly))
+            {
+              pappso::cbor::CborStreamWriter *p_cborWriter =
+                new pappso::cbor::CborStreamWriter(&mzcbor_file);
+
+              pappso::UiMonitorVoid void_monitor;
+
+              pappso::cbor::mzcbor::MzmlConvert mzml_convert(&void_monitor, p_cborWriter);
+
+              mzml_convert.read(&input_file);
+              mzcbor_file.flush();
+              input_file.close();
+              mzcbor_file.close();
+              if(!mzml_convert.errorString().isEmpty())
+                {
+                  throw pappso::PappsoException(
+                    QObject::tr("ERROR converting mzML file %1 to mzCBOR file %2 :\n%3")
+                      .arg(input_file_name)
+                      .arg(output_file_name)
+                      .arg(mzml_convert.errorString()));
+                }
+
+              delete p_cborWriter;
+              if(write_index)
+                {
+                  QString mzcbor_index_filename = output_file_name.append(".idx");
+                  QFile mzcbor_index_file;
+                  mzcbor_index_file.setFileName(mzcbor_index_filename);
+                  mzcbor_index_file.open(QIODevice::WriteOnly);
+                  pappso::cbor::CborStreamWriter *index_writer =
+                    new pappso::cbor::CborStreamWriter(&mzcbor_index_file);
+                  mzml_convert.writeMzcborIndex(index_writer);
+                  mzcbor_index_file.flush();
+                  mzcbor_index_file.close();
+                  delete index_writer;
+                }
+            }
+        }
+    }
+}
+
 
 int
 main(int argc, char **argv)
