@@ -13,17 +13,16 @@ QPointFJs::QPointFJs(double x, double y, QObject *parent) : QObject(parent), m_p
 {
 }
 
-QPointFJs::QPointFJs(const QPointF &pointf, QObject *parent)
-  : QObject(parent), m_pointf(pointf)
+QPointFJs::QPointFJs(const QPointF &pointf, QObject *parent) : QObject(parent), m_pointf(pointf)
 {
 }
 
 void
 QPointFJs::setX(double x)
 {
-  if(m_pointf.x()!= x)
+  if(m_pointf.x() != x)
     {
-      m_pointf.rx()= x;
+      m_pointf.rx() = x;
       emit xChanged();
     }
 }
@@ -38,9 +37,9 @@ QPointFJs::x() const
 void
 QPointFJs::setY(double y)
 {
-  if(m_pointf.y()!= y)
+  if(m_pointf.y() != y)
     {
-      m_pointf.ry()= y;
+      m_pointf.ry() = y;
       emit yChanged();
     }
 }
