@@ -32,7 +32,8 @@
 #include "pappsomspp/core/msrun/private/timsmsrunreaderms2.h"
 
 
-pappso::masschroq::MsRun::MsRun(pappso::MsRunReaderSPtr msrun_reader) : msp_msRunReader(msrun_reader)
+pappso::masschroq::MsRun::MsRun(pappso::MsRunReaderSPtr msrun_reader)
+  : msp_msRunReader(msrun_reader)
 {
 
   pappso::TimsMsRunReaderMs2 *tims2_reader =
