@@ -245,37 +245,44 @@ MsFileAccessor::getMsRunIds()
 
   // Try the TimsData reader
 
-  QString tims_dir = m_fileName;
-  if(!QFileInfo(tims_dir).isDir())
+  try
     {
-      tims_dir = QFileInfo(m_fileName).absolutePath();
-    }
-
-  TimsMsFileReader tims_file_reader(tims_dir);
-
-  ms_run_ids = tims_file_reader.getMsRunIds(m_xmlPrefix);
-
-  if(ms_run_ids.size())
-    {
-      qDebug() << "Might well be handled using the Bruker code";
-
-      m_fileName       = tims_dir;
-      m_fileFormat     = tims_file_reader.getFileFormat();
-      m_fileReaderType = Enums::FileReaderType::tims;
-
-      auto pref = m_preferredFileReaderTypeMap.find(m_fileFormat);
-      if(pref != m_preferredFileReaderTypeMap.end())
+      QString tims_dir = m_fileName;
+      if(!QFileInfo(tims_dir).isDir())
         {
-          m_fileReaderType = pref->second;
+          tims_dir = QFileInfo(m_fileName).absolutePath();
         }
 
-      qDebug() << "Returning Bruker::tims ms run(s)."
-               << "with preferred reader type:" << Utils::fileReaderTypeAsString(m_fileReaderType);
+      TimsMsFileReader tims_file_reader(tims_dir);
 
-      return ms_run_ids;
+      ms_run_ids = tims_file_reader.getMsRunIds(m_xmlPrefix);
+
+      if(ms_run_ids.size())
+        {
+          qDebug() << "Might well be handled using the Bruker code";
+
+          m_fileName       = tims_dir;
+          m_fileFormat     = tims_file_reader.getFileFormat();
+          m_fileReaderType = Enums::FileReaderType::tims;
+
+          auto pref = m_preferredFileReaderTypeMap.find(m_fileFormat);
+          if(pref != m_preferredFileReaderTypeMap.end())
+            {
+              m_fileReaderType = pref->second;
+            }
+
+          qDebug() << "Returning Bruker::tims ms run(s)."
+                   << "with preferred reader type:"
+                   << Utils::fileReaderTypeAsString(m_fileReaderType);
+
+          return ms_run_ids;
+        }
+    }
+  catch(const pappso::ExceptionNotRecognized &error)
+    {
+      qDebug() << "The Tims reader did not work.";
     }
 
-  qDebug() << "The Tims reader did not work.";
 
   // Try the Baf->ascii export format from Bruker Compass
 
@@ -430,7 +437,9 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
   if(m_fileName != ms_run_id->getFileName())
     throw(
       ExceptionNotPossible(QObject::tr("The MsRunId instance must have the name file name as the "
-                                       "MsFileAccessor.")));
+                                       "MsFileAccessor. %1 != %2")
+                             .arg(m_fileName)
+                             .arg(ms_run_id->getFileName())));
 
   if(m_fileFormat == Enums::MsDataFormat::mzcbor)
     {
