@@ -8,6 +8,7 @@
 #include "pappsomspp/core/types.h"
 #include "msfilereader.h"
 #include "pappsomspp/core/msrun/msrunid.h"
+#include "pappsomspp/core/processing/cbor/mzcbor/mzcborindexreader.h"
 #include "pappsomspp/core/processing/cbor/mzcbor/mzcborreaderbase.h"
 
 
@@ -35,5 +36,6 @@ class MzcborMsFileReader : MsFileReader
   std::vector<pwiz::msdata::MSDataPtr> m_msDataPtrVector;
 
   pappso::cbor::mzcbor::MzcborReaderBase m_mzcborReaderBase;
+  pappso::cbor::mzcbor::MzcborIndexReader m_mzcborIndexReader;
 };
 } // namespace pappso
