@@ -104,6 +104,23 @@ MzcborMsRunReader::initialize()
           m_spectrumIndexPositionInFile =
             index_reader.getRunAndSpectrumOffsetList().at(run_position);
 
+
+          if(index_reader.getRunAndSpectrumTotalIonCountList().size() > run_position)
+            {
+              m_spectrumTotalIonCountList =
+                index_reader.getRunAndSpectrumTotalIonCountList().at(run_position);
+            }
+          if(index_reader.getRunAndSpectrumMsLevelList().size() > run_position)
+            {
+              m_spectrumMsLevelList = index_reader.getRunAndSpectrumMsLevelList().at(run_position);
+            }
+
+          if(index_reader.getRunAndSpectrumRtList().size() > run_position)
+            {
+              m_spectrumRtList = index_reader.getRunAndSpectrumRtList().at(run_position);
+            }
+          // qFatal() << m_spectrumTotalIonCountList.size();
+
           std::size_t i = 0;
           for(const QString &native_id : index_reader.getRunAndSpectrumIdList().at(run_position))
             {
@@ -532,15 +549,83 @@ MzcborMsRunReader::fillMzcborSpectrum(std::size_t spectrum_index,
   // qDebug() << spectrum_index << " " << m_spectrumIndexPositionInFile[spectrum_index-1];
 
 
-  mpa_mzcborFileDevice->seek(m_spectrumIndexPositionInFile[spectrum_index]);
-  pappso::cbor::CborStreamReader cbor_stream_reader(mpa_mzcborFileDevice);
-  cbor_stream_reader.setDevice(mpa_mzcborFileDevice);
+  if(mpa_mzcborFileDevice->seek(m_spectrumIndexPositionInFile[spectrum_index]))
+    {
+      pappso::cbor::CborStreamReader cbor_stream_reader(mpa_mzcborFileDevice);
+      cbor_stream_reader.setDevice(mpa_mzcborFileDevice);
 
 
-  spectrum.fromCbor(cbor_stream_reader, want_binary_data);
-  // cbor_stream_reader.leaveContainer();
+      try
+        {
+          spectrum.fromCbor(cbor_stream_reader, want_binary_data);
+        }
+      catch(const pappso::PappsoException &error)
+        {
 
+          throw pappso::PappsoException(QObject::tr("ERROR reading spectrum %1 cbor:\n%2")
+                                          .arg(spectrum_index)
+                                          .arg(error.qwhat()));
+        }
+      // cbor_stream_reader.leaveContainer();
+
+      if(spectrum.id.isEmpty())
+        {
+          throw pappso::PappsoException(
+            QObject::tr("ERROR reading spectrum %1 cbor:\nspectrum not found").arg(spectrum_index));
+        }
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("ERROR reading spectrum %1 cbor:\nseek failed").arg(spectrum_index));
+    }
   // mzcbor_file.close();
 }
 
+
+Trace
+MzcborMsRunReader::getTicChromatogram()
+{
+  qDebug() << m_spectrumMsLevelList.size() << " " << m_spectrumTotalIonCountList.size();
+  Trace chromatogram;
+  if((m_spectrumTotalIonCountList.size() > 0) &&
+     (m_spectrumMsLevelList.size() == m_spectrumTotalIonCountList.size()))
+    {
+      for(std::size_t i = 0; i < m_spectrumTotalIonCountList.size(); i++)
+        {
+          if(m_spectrumMsLevelList.at(i) == 1)
+            {
+              chromatogram.push_back(
+                {m_spectrumRtList.at(i), (double)m_spectrumTotalIonCountList.at(i)});
+            }
+        }
+    }
+  else
+    {
+      return MsRunReader::getTicChromatogram();
+    }
+  return chromatogram;
+}
+std::vector<double>
+MzcborMsRunReader::getRetentionTimeLine()
+{
+  qDebug();
+  std::vector<double> time_line;
+  if((m_spectrumRtList.size() > 0) && (m_spectrumMsLevelList.size() == m_spectrumRtList.size()))
+    {
+      for(std::size_t i = 0; i < m_spectrumRtList.size(); i++)
+        {
+          if(m_spectrumMsLevelList.at(i) == 1)
+            {
+              time_line.push_back(m_spectrumRtList.at(i));
+            }
+        }
+    }
+  else
+    {
+      return MsRunReader::getRetentionTimeLine();
+    }
+  return time_line;
+}
+
 } // namespace pappso
