@@ -103,6 +103,8 @@ class MzcborMsRunReader : public MsRunReader
   const std::vector<qint64> &getSpectrumIndexPositionInFile() const;
 
   virtual const OboPsiModTerm getOboPsiModTermInstrumentModelName() const override;
+  virtual Trace getTicChromatogram() override;
+  virtual std::vector<double> getRetentionTimeLine() override;
 
   protected:
   virtual void initialize() override;
@@ -119,6 +121,9 @@ class MzcborMsRunReader : public MsRunReader
   private:
   QFileInfo m_cborFileInfo;
   std::vector<qint64> m_spectrumIndexPositionInFile;
+  std::vector<qint64> m_spectrumTotalIonCountList;
+  std::vector<std::uint8_t> m_spectrumMsLevelList;
+  std::vector<double> m_spectrumRtList;
   std::map<QString, std::size_t> m_nativeId2SpectrumIndexMap;
   std::map<std::size_t, std::size_t> m_scan2SpectrumIndexMap;
 
