@@ -1169,7 +1169,7 @@ PwizMsRunReader::setGlobalLocaleToCurrentOs(const std::string &environment_local
       // locale
       std::setlocale(LC_ALL, environment_locale.c_str());
 #else
-      std::locale::global(std::locale(""));  // sets locale according to OS environment
+      std::locale::global(std::locale("")); // sets locale according to OS environment
 #endif
     }
   catch(std::exception &error)
@@ -1224,8 +1224,7 @@ pappso::PwizMsRunReader::getOboPsiModTermInstrumentModelName() const
 
       for(auto &param_group : msp_msData.get()->paramGroupPtrs)
         {
-          for(auto &cv_param : param_group.get()->cvParams)
-            {
+          for (const auto &cv_param : param_group.get()->cvParams) {
               if(cv_param.cvid == pwiz::cv::CVID::MS_Q_Exactive)
                 {
                   term = psims_map.getOboPsiModTermWithAccession("MS:1001911");
@@ -1342,7 +1341,7 @@ pappso::PwizMsRunReader::getOboPsiModTermInstrumentModelName() const
                 {
                   term = psims_map.getOboPsiModTermWithAccession("MS:1003378");
                 }
-            }
+          }
         }
     }
   else
