@@ -232,7 +232,8 @@ Peptide::addAaModification(AaModificationP aaModification, unsigned int position
 }
 
 void
-Peptide::addAaModificationOnAllAminoAcid(AaModificationP aaModification, Enums::AminoAcidChar amino_acid)
+Peptide::addAaModificationOnAllAminoAcid(AaModificationP aaModification,
+                                         Enums::AminoAcidChar amino_acid)
 {
 
   for(auto &aa : *this)
@@ -603,8 +604,8 @@ Peptide::setNterModification(AaModificationP mod)
     }
   else
     {
-      throw ExceptionNotPossible(QObject::tr("modification is not a peptide Nter modification : %1")
-                                   .arg(mod->getAccession()));
+      throw ExceptionNotPossible(
+        QObject::tr("modification is not a peptide Nter modification : mod == nulptr"));
     }
 }
 void
@@ -618,8 +619,8 @@ Peptide::setCterModification(AaModificationP mod)
     }
   else
     {
-      throw ExceptionNotPossible(QObject::tr("modification is not a peptide Cter modification : %1")
-                                   .arg(mod->getAccession()));
+      throw ExceptionNotPossible(
+        QObject::tr("modification is not a peptide Cter modification : mod == nulptr"));
     }
 }
 
