@@ -42,20 +42,18 @@ PeptideFragmentIon::PeptideFragmentIon(const PeptideFragmentSp &sp_fragment,
 {
 }
 
-PeptideFragmentIon::PeptideFragmentIon(
-  const PeptideFragmentSp &sp_fragment,
-  Enums::PeptideIon ion_type,
-  unsigned int number_of_neutral_phospho_loss)
+PeptideFragmentIon::PeptideFragmentIon(const PeptideFragmentSp &sp_fragment,
+                                       Enums::PeptideIon ion_type,
+                                       unsigned int number_of_neutral_phospho_loss)
   : msp_fragment(sp_fragment), m_ionType(ion_type)
 {
   m_mass                     = msp_fragment.get()->getMass();
   PeptideDirection direction = msp_fragment.get()->getPeptideIonDirection();
   if(direction != pappso::getPeptideIonDirection(m_ionType))
     {
-      throw PappsoException(
-        QString("Enums::PeptideIon %1 is not an %2 fragment")
-          .arg(PeptideFragmentIon::getPeptideIonName(m_ionType))
-          .arg(PeptideFragment::getPeptideIonDirectionName(direction)));
+      throw PappsoException(QString("Enums::PeptideIon %1 is not an %2 fragment")
+                              .arg(PeptideFragmentIon::getPeptideIonName(m_ionType))
+                              .arg(PeptideFragment::getPeptideIonDirectionName(direction)));
     }
   m_mass -= MASSH2O;
   switch(m_ionType)
@@ -63,14 +61,12 @@ PeptideFragmentIon::PeptideFragmentIon(
         // -MASSH2O
       case Enums::PeptideIon::yp:
         m_neutralPhosphoLossNumber = number_of_neutral_phospho_loss;
-        m_mass -=
-          ((MASSH2O + MASSPHOSPHORYLATEDR) * m_neutralPhosphoLossNumber);
+        m_mass -= ((MASSH2O + MASSPHOSPHORYLATEDR) * m_neutralPhosphoLossNumber);
         ion_type = Enums::PeptideIon::y;
         break;
       case Enums::PeptideIon::bp:
         m_neutralPhosphoLossNumber = number_of_neutral_phospho_loss;
-        m_mass -=
-          ((MASSH2O + MASSPHOSPHORYLATEDR) * m_neutralPhosphoLossNumber);
+        m_mass -= ((MASSH2O + MASSPHOSPHORYLATEDR) * m_neutralPhosphoLossNumber);
         ion_type = Enums::PeptideIon::b;
         break;
       default:
@@ -86,11 +82,8 @@ PeptideFragmentIon::PeptideFragmentIon(const PeptideFragmentIon &other)
 }
 
 
-PeptideFragmentIon::PeptideFragmentIon(
-  PeptideFragmentIon &&toCopy) // move constructor
-  : msp_fragment(std::move(toCopy.msp_fragment)),
-    m_ionType(toCopy.m_ionType),
-    m_mass(toCopy.m_mass)
+PeptideFragmentIon::PeptideFragmentIon(PeptideFragmentIon &&toCopy) // move constructor
+  : msp_fragment(std::move(toCopy.msp_fragment)), m_ionType(toCopy.m_ionType), m_mass(toCopy.m_mass)
 {
 }
 
@@ -115,23 +108,14 @@ PeptideFragmentIon::getCompletePeptideIonName(unsigned int charge) const
   plusstr          = plusstr.repeated(charge);
   if(m_ionType == Enums::PeptideIon::yp)
     {
-      return QString("y%1(-P%2)%3")
-        .arg(size)
-        .arg(m_neutralPhosphoLossNumber)
-        .arg(plusstr);
+      return QString("y%1(-P%2)%3").arg(size).arg(m_neutralPhosphoLossNumber).arg(plusstr);
     }
   else if(m_ionType == Enums::PeptideIon::bp)
     {
-      return QString("b%1(-P%2)%3")
-        .arg(size)
-        .arg(m_neutralPhosphoLossNumber)
-        .arg(plusstr);
+      return QString("b%1(-P%2)%3").arg(size).arg(m_neutralPhosphoLossNumber).arg(plusstr);
     }
 
-  return QString("%1%2%3")
-    .arg(getPeptideIonName(m_ionType))
-    .arg(size)
-    .arg(plusstr);
+  return QString("%1%2%3").arg(getPeptideIonName(m_ionType)).arg(size).arg(plusstr);
 }
 
 const QString
@@ -139,9 +123,7 @@ PeptideFragmentIon::getPeptideIonName() const
 {
   if((m_ionType == Enums::PeptideIon::yp) || (m_ionType == Enums::PeptideIon::bp))
     {
-      return QString("%1(%2)")
-        .arg(getPeptideIonName(m_ionType))
-        .arg(m_neutralPhosphoLossNumber);
+      return QString("%1(%2)").arg(getPeptideIonName(m_ionType)).arg(m_neutralPhosphoLossNumber);
     }
   return getPeptideIonName(m_ionType);
 }
@@ -249,8 +231,8 @@ PeptideFragmentIon::getPeptideIonColor(Enums::PeptideIon m_ionType)
         return QColor("blue");
         break;
       default:
-        throw PappsoException(QString("Enums::PeptideIon color not implemented %1")
-                                .arg(getPeptideIonName(m_ionType)));
+        throw PappsoException(
+          QString("Enums::PeptideIon color not implemented %1").arg(getPeptideIonName(m_ionType)));
         break;
     }
 }
@@ -524,8 +506,7 @@ PeptideFragmentIon::getNumberOfAtom(Enums::AtomIsotopeSurvey atom) const
               diff = +1;
               break;
             default:
-              throw PappsoException(
-                QObject::tr("Enums::PeptideIon name not implemented"));
+              throw PappsoException(QObject::tr("Enums::PeptideIon name not implemented"));
               break;
           }
         break;
