@@ -35,23 +35,19 @@
 namespace pappso
 {
 
-PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
-  const PeptideInterfaceSp &peptide, pappso_double minimum_ratio_to_compute)
+PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(const PeptideInterfaceSp &peptide,
+                                                     pappso_double minimum_ratio_to_compute)
   : msp_peptide(peptide)
 {
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
   //          << minimum_ratio_to_compute;
-  int number_of_fixed_oxygen =
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::O18) +
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::O17);
-  int number_of_fixed_sulfur =
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S33) +
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S34) +
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S36);
-  int number_of_fixed_nitrogen =
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::N15);
-  int number_of_fixed_hydrogen =
-    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::H2);
+  int number_of_fixed_oxygen = msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::O18) +
+                               msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::O17);
+  int number_of_fixed_sulfur = msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S33) +
+                               msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S34) +
+                               msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::S36);
+  int number_of_fixed_nitrogen = msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::N15);
+  int number_of_fixed_hydrogen = msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::H2);
 
   int total_carbon(msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::C) -
                    msp_peptide.get()->getNumberOfIsotope(Enums::Isotope::C13));
@@ -85,8 +81,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
   // Sulfur isotope list
   int total_sulfur(msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::S) -
                    number_of_fixed_sulfur);
-  std::list<PeptideNaturalIsotopeSp>::iterator it =
-    msp_peptide_natural_isotope_list.begin();
+  std::list<PeptideNaturalIsotopeSp>::iterator it = msp_peptide_natural_isotope_list.begin();
   while(it != msp_peptide_natural_isotope_list.end())
     {
       map_isotope = it->get()->getIsotopeMap();
@@ -105,8 +100,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
 
   // compute S33 abundance
   temp_list.resize(0);
@@ -116,15 +110,13 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
       // qDebug() << "peptide S33 " << it->get()->getFormula(1) << " "
       // <<it->get()->getIntensityRatio(1);
       map_isotope = it->get()->getIsotopeMap();
-      for(int nbS33 = 1; nbS33 <= (total_sulfur - map_isotope[Enums::Isotope::S34]);
-          nbS33++)
+      for(int nbS33 = 1; nbS33 <= (total_sulfur - map_isotope[Enums::Isotope::S34]); nbS33++)
         {
           map_isotope[Enums::Isotope::S33] = nbS33;
           PeptideNaturalIsotopeSp pepIsotopeS33 =
             std::make_shared<PeptideNaturalIsotope>(msp_peptide, map_isotope);
           temp_list.push_back(pepIsotopeS33);
-          if(pepIsotopeS33.get()->getIntensityRatio(1) <
-             minimum_ratio_to_compute)
+          if(pepIsotopeS33.get()->getIntensityRatio(1) < minimum_ratio_to_compute)
             {
               // it++;
               break;
@@ -132,8 +124,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
 
   // compute S36 abundance
   temp_list.resize(0);
@@ -149,8 +140,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
           PeptideNaturalIsotopeSp pepIsotopeS36 =
             std::make_shared<PeptideNaturalIsotope>(msp_peptide, map_isotope);
           temp_list.push_back(pepIsotopeS36);
-          if(pepIsotopeS36.get()->getIntensityRatio(1) <
-             minimum_ratio_to_compute)
+          if(pepIsotopeS36.get()->getIntensityRatio(1) < minimum_ratio_to_compute)
             {
               // it++;
               break;
@@ -158,8 +148,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
 
   // ******************************************************************
 
@@ -192,8 +181,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
   // ******************************************************************
 
 
@@ -202,9 +190,8 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
   temp_list.resize(0);
   // qDebug() << "PeptideNaturalIsotopeList::PeptideNaturalIsotopeList
   // total_oxygen";
-  unsigned int total_oxygen(
-    msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::O) -
-    number_of_fixed_oxygen);
+  unsigned int total_oxygen(msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::O) -
+                            number_of_fixed_oxygen);
   it = msp_peptide_natural_isotope_list.begin();
   while(it != msp_peptide_natural_isotope_list.end())
     {
@@ -228,8 +215,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
   // ******************************************************************
 
 
@@ -238,9 +224,8 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
   temp_list.resize(0);
   // qDebug() << "PeptideNaturalIsotopeList::PeptideNaturalIsotopeList
   // total_nitrogen";
-  unsigned int total_nitrogen(
-    msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::N) -
-    number_of_fixed_nitrogen);
+  unsigned int total_nitrogen(msp_peptide.get()->getNumberOfAtom(Enums::AtomIsotopeSurvey::N) -
+                              number_of_fixed_nitrogen);
   it = msp_peptide_natural_isotope_list.begin();
   while(it != msp_peptide_natural_isotope_list.end())
     {
@@ -264,8 +249,7 @@ PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
         }
       it++;
     }
-  msp_peptide_natural_isotope_list.insert(
-    it, temp_list.begin(), temp_list.end());
+  msp_peptide_natural_isotope_list.insert(it, temp_list.begin(), temp_list.end());
   // ******************************************************************
 
   // qDebug() << "PeptideNaturalIsotopeList::PeptideNaturalIsotopeList end
@@ -278,8 +262,7 @@ PeptideNaturalIsotopeList::makePeptideNaturalIsotopeListSp() const
   return std::make_shared<PeptideNaturalIsotopeList>(*this);
 }
 
-PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(
-  const PeptideNaturalIsotopeList &other)
+PeptideNaturalIsotopeList::PeptideNaturalIsotopeList(const PeptideNaturalIsotopeList &other)
   : msp_peptide(other.msp_peptide),
     msp_peptide_natural_isotope_list(other.msp_peptide_natural_isotope_list)
 {
@@ -292,16 +275,14 @@ PeptideNaturalIsotopeList::~PeptideNaturalIsotopeList()
 const std::map<unsigned int, pappso_double>
 PeptideNaturalIsotopeList::getIntensityRatioPerIsotopeNumber() const
 {
-  std::list<PeptideNaturalIsotopeSp>::const_iterator it =
-    msp_peptide_natural_isotope_list.begin();
+  std::list<PeptideNaturalIsotopeSp>::const_iterator it = msp_peptide_natural_isotope_list.begin();
   std::map<unsigned int, pappso_double> map_isotope_number;
 
   while(it != msp_peptide_natural_isotope_list.end())
     {
       unsigned int number = it->get()->getIsotopeNumber();
       std::pair<std::map<unsigned int, pappso_double>::iterator, bool> mapnew =
-        map_isotope_number.insert(
-          std::pair<unsigned int, pappso_double>(number, 0));
+        map_isotope_number.insert(std::pair<unsigned int, pappso_double>(number, 0));
       if(mapnew.second == false)
         {
           // mapit = map_isotope_number.insert(std::pair<unsigned
@@ -334,10 +315,8 @@ PeptideNaturalIsotopeList::getByIsotopeNumber(unsigned int isotope_number,
     }
   std::sort(v_isotope_list.begin(),
             v_isotope_list.end(),
-            [charge](const PeptideNaturalIsotopeSp &m,
-                     const PeptideNaturalIsotopeSp &n) {
-              return (m.get()->getIntensityRatio(charge) >
-                      n.get()->getIntensityRatio(charge));
+            [charge](const PeptideNaturalIsotopeSp &m, const PeptideNaturalIsotopeSp &n) {
+              return (m.get()->getIntensityRatio(charge) > n.get()->getIntensityRatio(charge));
             });
   return v_isotope_list;
 }
@@ -364,8 +343,7 @@ getByIntensityRatioByIsotopeNumber(const PeptideInterfaceSp &peptide,
 
   std::vector<unsigned int> previousIsotopeRank;
   bool isEmpty = false;
-  for(askedIsotopeRank = 1;
-      (askedIsotopeRank < maxAskedIsotopeRank) && (!isEmpty);
+  for(askedIsotopeRank = 1; (askedIsotopeRank < maxAskedIsotopeRank) && (!isEmpty);
       askedIsotopeRank++)
     {
       PeptideNaturalIsotopeAverage isotopeAverage(
@@ -378,12 +356,10 @@ getByIntensityRatioByIsotopeNumber(const PeptideInterfaceSp &peptide,
         {
           if(std::find(previousIsotopeRank.begin(),
                        previousIsotopeRank.end(),
-                       isotopeAverage.getIsotopeRank()) ==
-             previousIsotopeRank.end())
+                       isotopeAverage.getIsotopeRank()) == previousIsotopeRank.end())
             { // not Found
               previousIsotopeRank.push_back(isotopeAverage.getIsotopeRank());
-              v_isotopeAverageList.push_back(
-                isotopeAverage.makePeptideNaturalIsotopeAverageSp());
+              v_isotopeAverageList.push_back(isotopeAverage.makePeptideNaturalIsotopeAverageSp());
             }
         }
     }
@@ -393,18 +369,15 @@ getByIntensityRatioByIsotopeNumber(const PeptideInterfaceSp &peptide,
   // qDebug() << "getByIntensityRatioByIsotopeNumber comp";
   std::sort(v_isotopeAverageList.begin(),
             v_isotopeAverageList.end(),
-            [](const PeptideNaturalIsotopeAverageSp &m,
-               const PeptideNaturalIsotopeAverageSp &n) {
-              return (m.get()->getIntensityRatio() >
-                      n.get()->getIntensityRatio());
+            [](const PeptideNaturalIsotopeAverageSp &m, const PeptideNaturalIsotopeAverageSp &n) {
+              return (m.get()->getIntensityRatio() > n.get()->getIntensityRatio());
             });
 
   cumulativeRatio = 0;
   auto it         = v_isotopeAverageList.begin();
   v_isotopeAverageListResult.clear();
   // qDebug() << "getByIntensityRatioByIsotopeNumber cumul";
-  while((it != v_isotopeAverageList.end()) &&
-        (cumulativeRatio < minimumIntensity))
+  while((it != v_isotopeAverageList.end()) && (cumulativeRatio < minimumIntensity))
     {
       cumulativeRatio += it->get()->getIntensityRatio();
       v_isotopeAverageListResult.push_back(*it);
@@ -422,26 +395,22 @@ getByIntensityRatioByIsotopeNumber(const PeptideInterfaceSp &peptide,
  *
  * */
 std::vector<PeptideNaturalIsotopeAverageSp>
-PeptideNaturalIsotopeList::getByIntensityRatio(
-  unsigned int charge,
-  PrecisionPtr precision,
-  pappso_double minimumIntensityRatio) const
+PeptideNaturalIsotopeList::getByIntensityRatio(unsigned int charge,
+                                               PrecisionPtr precision,
+                                               pappso_double minimumIntensityRatio) const
 {
 
   // qDebug() << "PeptideNaturalIsotopeList::getByIntensityRatio begin";
-  std::vector<PeptideNaturalIsotopeAverageSp>
-    peptide_natural_isotope_average_list;
+  std::vector<PeptideNaturalIsotopeAverageSp> peptide_natural_isotope_average_list;
 
   std::map<unsigned int, pappso::pappso_double> map_isotope_number =
     getIntensityRatioPerIsotopeNumber();
-  std::vector<std::pair<unsigned int, pappso::pappso_double>>
-    sorted_number_ratio;
+  std::vector<std::pair<unsigned int, pappso::pappso_double>> sorted_number_ratio;
 
   for(unsigned int i = 0; i < map_isotope_number.size(); i++)
     {
       sorted_number_ratio.push_back(
-        std::pair<unsigned int, pappso::pappso_double>(i,
-                                                       map_isotope_number[i]));
+        std::pair<unsigned int, pappso::pappso_double>(i, map_isotope_number[i]));
       unsigned int asked_rank = 0;
       unsigned int given_rank = 0;
       bool more_rank          = true;
@@ -470,12 +439,11 @@ PeptideNaturalIsotopeList::getByIntensityRatio(
 
 
   // sort by intensity ratio
-  std::sort(sorted_number_ratio.begin(),
-            sorted_number_ratio.end(),
-            [](const std::pair<unsigned int, pappso::pappso_double> &m,
-               const std::pair<unsigned int, pappso::pappso_double> &n) {
-              return (m.second > n.second);
-            });
+  std::sort(
+    sorted_number_ratio.begin(),
+    sorted_number_ratio.end(),
+    [](const std::pair<unsigned int, pappso::pappso_double> &m,
+       const std::pair<unsigned int, pappso::pappso_double> &n) { return (m.second > n.second); });
 
 
   double cumulativeRatio = 0;
@@ -496,15 +464,13 @@ PeptideNaturalIsotopeList::getByIntensityRatio(
   auto it_remove =
     std::remove_if(peptide_natural_isotope_average_list.begin(),
                    peptide_natural_isotope_average_list.end(),
-                   [selected_isotope_number_list](
-                     const PeptideNaturalIsotopeAverageSp &average) {
+                   [selected_isotope_number_list](const PeptideNaturalIsotopeAverageSp &average) {
                      auto it = std::find(selected_isotope_number_list.begin(),
                                          selected_isotope_number_list.end(),
                                          average.get()->getIsotopeNumber());
                      return (it == selected_isotope_number_list.end());
                    });
-  peptide_natural_isotope_average_list.erase(
-    it_remove, peptide_natural_isotope_average_list.end());
+  peptide_natural_isotope_average_list.erase(it_remove, peptide_natural_isotope_average_list.end());
   return peptide_natural_isotope_average_list;
 }
 
