@@ -32,13 +32,13 @@
 void
 pappso::cbor::mzcbor::CvParam::fromCbor(CborStreamReader &reader)
 {
-  qDebug();
+  // qDebug();
   reader.enterContainer();
   QString attribute_cvparam;
   while(reader.hasNext())
     {
       reader.decodeString(attribute_cvparam);
-      qDebug() << attribute_cvparam;
+      // qDebug() << attribute_cvparam;
       if(attribute_cvparam == "cvRef")
         {
           reader.decodeString(cvRef);
@@ -112,7 +112,7 @@ pappso::cbor::mzcbor::CvParam::fromCbor(CborStreamReader &reader)
 void
 pappso::cbor::mzcbor::CvParam::fromMzml(QXmlStreamReader &reader)
 {
-  qDebug();
+  // qDebug();
   for(auto &the_attribute : reader.attributes())
     {
       if(the_attribute.name() == "cvRef")
@@ -146,7 +146,7 @@ pappso::cbor::mzcbor::CvParam::fromMzml(QXmlStreamReader &reader)
     }
 
   reader.readNextStartElement();
-  qDebug();
+  // qDebug();
 }
 
 void
@@ -181,7 +181,7 @@ pappso::cbor::mzcbor::CvParam::toCbor(CborStreamWriter &writer)
 std::map<QString, pappso::cbor::mzcbor::CvParam>
 pappso::cbor::mzcbor::CvParam::getCvParamsMapFromCbor(CborStreamReader &reader)
 {
-  qDebug();
+  // qDebug();
   std::map<QString, CvParam> accession_values;
   reader.enterContainer(); // start array
 
@@ -244,6 +244,54 @@ pappso::cbor::mzcbor::CvParam::toMzml(QXmlStreamWriter &writer)
   writer.writeEndElement(); // cvParam
 }
 
+std::uint8_t
+pappso::cbor::mzcbor::CvParam::getExpectedUint8() const
+{
+  bool ok(false);
+  int i = valueStr.toInt(&ok);
+  if(ok)
+    {
+      return (std::uint8_t)i;
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("cvParam value string is not an integer %1 %2").arg(accession).arg(valueStr));
+    }
+}
+
+qint64
+pappso::cbor::mzcbor::CvParam::getExpectedQint64() const
+{
+  bool ok(false);
+  qint64 i = valueStr.toLongLong(&ok);
+  if(ok)
+    {
+      return i;
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("cvParam value string is not an integer %1 %2").arg(accession).arg(valueStr));
+    }
+}
+
+double
+pappso::cbor::mzcbor::CvParam::getExpectedDouble() const
+{
+  bool ok(false);
+  double i = valueStr.toDouble(&ok);
+  if(ok)
+    {
+      return i;
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("cvParam value string is not a double %1 %2").arg(accession).arg(valueStr));
+    }
+}
+
 
 void
 pappso::cbor::mzcbor::CvParam::xmlValueToCbor(CborStreamWriter &writer,
