@@ -57,6 +57,10 @@ struct CvParam
 
   void setValue(const QString &value_str);
 
+  std::uint8_t getExpectedUint8() const;
+  double getExpectedDouble() const;
+  qint64 getExpectedQint64() const;
+
   QString cvRef;
   QString accession;
   double valueDouble;
