@@ -91,6 +91,9 @@ class PMSPP_LIB_DECL MzmlConvert : public XmlStreamReaderInterface
   std::vector<QString> m_runIdList;
   std::vector<std::vector<qint64>> m_runAndSpectrumOffsetList;
   std::vector<std::vector<QString>> m_runAndSpectrumIdList;
+  std::vector<std::vector<qint64>> m_runAndSpectrumTotalIonCountList;
+  std::vector<std::vector<std::uint8_t>> m_runAndSpectrumMsLevelList;
+  std::vector<std::vector<double>> m_runAndSpectrumRtList;
   QString m_uuid;
 };
 } // namespace mzcbor
