@@ -287,9 +287,9 @@ psm::CborScanMapBase::filterPsmListUniqueUniqueProforma()
       all_psm_list.push_back({psm_map.value("proforma").toString(), psm_map});
     }
   qDebug();
-  std::sort(all_psm_list.begin(),
-            all_psm_list.end(),
-            [](uniquePsmResult &a, uniquePsmResult &b) { return a.proforma > b.proforma; });
+  std::sort(all_psm_list.begin(), all_psm_list.end(), [](uniquePsmResult &a, uniquePsmResult &b) {
+    return a.proforma > b.proforma;
+  });
 
   qDebug();
   std::vector<uniquePsmResult> unique_psm_list;
