@@ -30,6 +30,8 @@
 #include "pappsomspp/core/massspectrum/qualifiedmassspectrum.h"
 #include "pappsomspp/core/processing/cbor/psm/psmproteinmap.h"
 
+#include "pappsomspp/export-import-config.h"
+
 namespace pappso
 {
 namespace cbor
@@ -42,7 +44,7 @@ class PsmFileScanProcess;
 /**
  * @todo write docs
  */
-class CborScanMapBase : public QCborMap
+class PMSPP_LIB_DECL CborScanMapBase : public QCborMap
 {
   public:
   /**
