@@ -28,6 +28,7 @@
 
 #include "../psmfilescanprocessandcopy.h"
 #include <QJsonObject>
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso::cbor::psm
 {
@@ -36,7 +37,7 @@ class PsmSpecGlobScan;
 /**
  * @todo write docs
  */
-class PsmSpecGlob : public PsmFileScanProcessAndCopy
+class PMSPP_LIB_DECL PsmSpecGlob : public PsmFileScanProcessAndCopy
 {
   friend PsmSpecGlobScan;
 
