@@ -117,7 +117,8 @@ pappso::cbor::psm::PsmSpecPeptidOms::proteinMapReady(pappso::UiMonitorInterface
 
 
 void
-pappso::cbor::psm::PsmSpecPeptidOms::parameterMapReady(pappso::UiMonitorInterface &monitor)
+pappso::cbor::psm::PsmSpecPeptidOms::parameterMapReady(pappso::UiMonitorInterface &monitor
+                                                       [[maybe_unused]])
 {
 
   QCborMap cbor_peptidoms_parameters = QCborValue::fromJsonValue(m_specpeptidomsParameters).toMap();
@@ -143,7 +144,7 @@ pappso::cbor::psm::PsmSpecPeptidOms::getAaCode() const
 
 pappso::cbor::psm::PsmSpecPeptidOmsScan::PsmSpecPeptidOmsScan(
   const pappso::cbor::psm::PsmSpecPeptidOms &psm_specpeptidoms,
-  pappso::PrecisionPtr fragment_tolerance)
+  pappso::PrecisionPtr fragment_tolerance [[maybe_unused]])
   : CborScanMapBase(psm_specpeptidoms)
 {
   mp_psmSpecPeptidOms = &psm_specpeptidoms;
