@@ -30,6 +30,7 @@
 
 #include <QCborMap>
 #include "pappsomspp/core/massspectrum/qualifiedmassspectrum.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
@@ -40,7 +41,7 @@ namespace psm
 /**
  * @brief utilities to help managing data in PSM CBOR data file
  */
-class PsmCborUtils
+class PMSPP_LIB_DECL PsmCborUtils
 {
   public:
   struct PsmProteinRef
