@@ -39,14 +39,29 @@ namespace cbor
 namespace psm
 {
 
-PsmFileReaderBase::PsmFileReaderBase()
+PsmFileReaderBase::PsmFileReaderBase() : CborStreamReaderInterface()
 {
 }
 
 PsmFileReaderBase::~PsmFileReaderBase()
 {
-  if(mpa_cborReader != nullptr)
-    delete mpa_cborReader;
+  // qWarning() << "~PsmFileReaderBase";
+}
+
+
+void
+PsmFileReaderBase::readCbor(QIODevice *cborp, pappso::UiMonitorInterface &monitor)
+{
+
+  qDebug();
+  initCborReader(cborp);
+
+  qDebug();
+  if(mpa_cborReader->isMap())
+    {
+      readRoot(monitor);
+    }
+  qDebug();
 }
 
 void
@@ -63,10 +78,6 @@ PsmFileReaderBase::readCbor(QFile *cborp, pappso::UiMonitorInterface &monitor)
   qDebug();
 }
 
-void
-PsmFileReaderBase::close()
-{
-}
 
 bool
 PsmFileReaderBase::currentProteinRefListContainsDecoy() const
@@ -100,11 +111,14 @@ PsmFileReaderBase::readRoot(pappso::UiMonitorInterface &monitor)
   getExpectedString();
   if(m_expectedString == "informations")
     {
+      qDebug() << m_expectedString;
       readInformations(monitor);
       getExpectedString();
 
+      qDebug() << m_expectedString;
       if(m_expectedString == "log")
         {
+          qDebug() << m_expectedString;
           readLog(monitor);
           getExpectedString();
         }
@@ -116,9 +130,11 @@ PsmFileReaderBase::readRoot(pappso::UiMonitorInterface &monitor)
       throw pappso::PappsoException("ERROR: expecting informations element");
     }
 
+  qDebug() << m_expectedString;
 
   if(m_expectedString == "parameter_map")
     {
+      qDebug();
       readParameterMap(monitor);
     }
   else
@@ -200,7 +216,7 @@ PsmFileReaderBase::readInformations(pappso::UiMonitorInterface &monitor [[maybe_
 }
 
 void
-PsmFileReaderBase::readLog(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::readLog(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   bool is_ok;
   // m_cborInformations.clear();
@@ -281,6 +297,7 @@ PsmFileReaderBase::readPsmProteinRef(bool &is_ok)
 PsmFile
 PsmFileReaderBase::readPsmFile(bool &is_ok)
 {
+  is_ok = false;
   PsmFile file;
   mpa_cborReader->enterContainer();
   getExpectedString();
@@ -290,6 +307,7 @@ PsmFileReaderBase::readPsmFile(bool &is_ok)
         {
           throw pappso::PappsoException("file name is not a string");
         }
+      is_ok = true;
     }
   else
     {
@@ -585,48 +603,48 @@ PsmFileReaderBase::psmReady(pappso::UiMonitorInterface &monitor [[maybe_unused]]
 }
 
 void
-PsmFileReaderBase::informationsReady(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::informationsReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::parameterMapReady(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::parameterMapReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::logReady(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::logReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 
 void
-PsmFileReaderBase::fastaFilesReady(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::fastaFilesReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::proteinMapReady(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::proteinMapReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::sampleStarted(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::sampleStarted(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::scanStarted(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::scanStarted(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::scanFinished(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::scanFinished(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
 void
-PsmFileReaderBase::sampleFinished(pappso::UiMonitorInterface &monitor)
+PsmFileReaderBase::sampleFinished(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
 }
 
