@@ -119,7 +119,7 @@ PsmFileScanProcess::processBufferScan(pappso::UiMonitorInterface &monitor)
 }
 
 void
-PsmFileScanProcess::processBufferScanDone(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcess::processBufferScanDone(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   // you decide what to do with processed scans
 }
