@@ -110,14 +110,14 @@ PsmFileScanProcessAndCopy::close()
 }
 
 void
-PsmFileScanProcessAndCopy::informationsReady(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::informationsReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   mp_cborOutput->writeInformations("pappsomspp_copy", Utils::getVersion(), "psm", m_operation);
 }
 
 
 void
-PsmFileScanProcessAndCopy::logReady(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::logReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   m_cborLog.append(m_cborInformations);
   mp_cborOutput->append("log");
@@ -125,14 +125,14 @@ PsmFileScanProcessAndCopy::logReady(pappso::UiMonitorInterface &monitor)
 }
 
 void
-PsmFileScanProcessAndCopy::parameterMapReady(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::parameterMapReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   mp_cborOutput->append("parameter_map");
   mp_cborOutput->writeCborMap(m_cborParameterMap);
 }
 
 void
-PsmFileScanProcessAndCopy::fastaFilesReady(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::fastaFilesReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   // "target_fasta_files": ["zea_mays.fasta", "contaminant.fasta"],
   if(!m_targetFastaFiles.isEmpty())
@@ -150,7 +150,7 @@ PsmFileScanProcessAndCopy::fastaFilesReady(pappso::UiMonitorInterface &monitor)
 }
 
 void
-PsmFileScanProcessAndCopy::proteinMapReady(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::proteinMapReady(pappso::UiMonitorInterface &monitor [[maybe_unused]])
 {
   if(mp_copyCborOutput == nullptr)
     {
@@ -166,7 +166,8 @@ PsmFileScanProcessAndCopy::proteinMapReady(pappso::UiMonitorInterface &monitor)
 
 
 void
-PsmFileScanProcessAndCopy::processBufferScanDone(pappso::UiMonitorInterface &monitor)
+PsmFileScanProcessAndCopy::processBufferScanDone(pappso::UiMonitorInterface &monitor
+                                                 [[maybe_unused]])
 {
 
   // monitor.setStatus(QObject::tr("PsmFileScanProcessAndCopy::processBufferScanDone"));
