@@ -27,8 +27,11 @@
  ******************************************************************************/
 #pragma once
 
+#include <QBuffer>
+
 #include "psmfilescanprocess.h"
 #include "pappsomspp/core/processing/cbor/cborstreamwriter.h"
+#include "pappsomspp/export-import-config.h"
 
 
 namespace pappso
@@ -42,7 +45,7 @@ namespace psm
  * @brief Basic PSM file reader to process scan (parallelized scan processing) and write a new
  * resulting PSM file
  */
-class PsmFileScanProcessAndCopy : public PsmFileScanProcess
+class PMSPP_LIB_DECL PsmFileScanProcessAndCopy : public PsmFileScanProcess
 {
   public:
   /**
