@@ -23,8 +23,7 @@ IntegrationScopeRhomb::IntegrationScopeRhomb() : IntegrationScopeBase()
   // qDebug() << "Constructing" << this;
 }
 
-IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points)
-  : m_points(points)
+IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points) : m_points(points)
 {
   // qDebug() << "Constructing" << this << "with" << m_points.size() << "points.";
 }
@@ -32,10 +31,7 @@ IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points)
 IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points,
                                              Enums::DataKind data_kind_x,
                                              Enums::DataKind data_kind_y)
-  : IntegrationScopeBase(),
-    m_points(points),
-    m_dataKindX(data_kind_x),
-    m_dataKindY(data_kind_y)
+  : IntegrationScopeBase(), m_points(points), m_dataKindX(data_kind_x), m_dataKindY(data_kind_y)
 {
   // qDebug() << "Constructing" << this << "with" << m_points.size() << "points."
   //          << "data_kind_x:" << static_cast<int>(data_kind_x)
@@ -718,14 +714,14 @@ IntegrationScopeRhomb::getWidth(double &width) const
   QPointF right_most_point;
 
   if(!getLeftMostPoint(left_most_point))
-   qFatal("Failed to get the left most point.");
+    qFatal("Failed to get the left most point.");
 
- if(!getRightMostPoint(right_most_point))
-  qFatal("Failed to get the right most point.");
+  if(!getRightMostPoint(right_most_point))
+    qFatal("Failed to get the right most point.");
 
- width = fabs(right_most_point.x() - left_most_point.x());
+  width = fabs(right_most_point.x() - left_most_point.x());
 
- return IntegrationScopeFeatures::SUCCESS;
+  return IntegrationScopeFeatures::SUCCESS;
 }
 
 IntegrationScopeFeatures
@@ -733,169 +729,168 @@ IntegrationScopeRhomb::getHeight(double &height) const
 {
   // See getWidth() for explanations.
 
- if(m_points.size() < 4)
-  qFatal("The IntegrationScopeRhomb has less than four points.");
+  if(m_points.size() < 4)
+    qFatal("The IntegrationScopeRhomb has less than four points.");
 
- // The height of the rhomboid is the entire span that it has on the y axis.
+  // The height of the rhomboid is the entire span that it has on the y axis.
 
- QPointF top_most_point;
- QPointF bottom_most_point;
+  QPointF top_most_point;
+  QPointF bottom_most_point;
 
- if(!getTopMostPoint(top_most_point))
-  qFatal("Failed to get the top most point.");
+  if(!getTopMostPoint(top_most_point))
+    qFatal("Failed to get the top most point.");
 
- if(!getBottomMostPoint(bottom_most_point))
-  qFatal("Failed to get the bottom most point.");
+  if(!getBottomMostPoint(bottom_most_point))
+    qFatal("Failed to get the bottom most point.");
 
- height = fabs(top_most_point.y() - bottom_most_point.y());
+  height = fabs(top_most_point.y() - bottom_most_point.y());
 
- return IntegrationScopeFeatures::SUCCESS;
+  return IntegrationScopeFeatures::SUCCESS;
 }
 
 IntegrationScopeFeatures
 IntegrationScopeRhomb::getRhombHorizontalSize(double &size) const
 {
- if(m_points.size() < 4)
-  qFatal("The IntegrationScopeRhomb has less than four points.");
+  if(m_points.size() < 4)
+    qFatal("The IntegrationScopeRhomb has less than four points.");
 
- // There are two kinds of rhomboid integration scopes:
+  // There are two kinds of rhomboid integration scopes:
 
- /*
-  *              4 +-----------+3
-  *                |          |
-  *              |          |
-  *            |          |
-  *          |          |
-  *        |          |
-  *       |          |
-  *     |          |
-  *    1+----------+2
-  *     ----width---
-  */
+  /*
+   *              4 +-----------+3
+   *                |          |
+   *              |          |
+   *            |          |
+   *          |          |
+   *        |          |
+   *       |          |
+   *     |          |
+   *    1+----------+2
+   *     ----width---
+   */
 
- // As visible here, the fixed size of the rhomboid (using the S key in the
- // plot widget) is the *horizontal* side (this is the plot context's
- // m_integrationScopeRhombWidth). In this case the height of the scope is 0.
+  // As visible here, the fixed size of the rhomboid (using the S key in the
+  // plot widget) is the *horizontal* side (this is the plot context's
+  // m_integrationScopeRhombWidth). In this case the height of the scope is 0.
 
- // and
+  // and
 
 
- /*
-  *                                       +3
-  *                                     . |
-  *                                   .   |
-  *                                 .     |
-  *                               .       +2
-  *                             .       .
-  *                           .       .
-  *                         .       .
-  *                      4+       .
-  *                     | |     .
-  *            height   | |   .
-  *                     | | .
-  *                      1+
-  *
-  */
+  /*
+   *                                       +3
+   *                                     . |
+   *                                   .   |
+   *                                 .     |
+   *                               .       +2
+   *                             .       .
+   *                           .       .
+   *                         .       .
+   *                      4+       .
+   *                     | |     .
+   *            height   | |   .
+   *                     | | .
+   *                      1+
+   *
+   */
 
- // As visible here, the fixed size of the rhomboid (using the S key in the
- // plot widget) is the *vertical* side (this is the plot context's
- // m_integrationScopeRhombHeight). In this case the width of the scope is 0.
+  // As visible here, the fixed size of the rhomboid (using the S key in the
+  // plot widget) is the *vertical* side (this is the plot context's
+  // m_integrationScopeRhombHeight). In this case the width of the scope is 0.
 
- // In this function we need to establish what kind of rhomboid (horizontal or
- // vertical) we are dealing with.
+  // In this function we need to establish what kind of rhomboid (horizontal or
+  // vertical) we are dealing with.
 
- // If the scope is horizontal, then two points of same y value (either top or
- // bottom) have different x values. That is, leftmost top point has the same y
- // value as the rightmost top point. Similarly, the leftmost bottom point has
- // the same y value as the rightmost bottom point.
+  // If the scope is horizontal, then two points of same y value (either top or
+  // bottom) have different x values. That is, leftmost top point has the same y
+  // value as the rightmost top point. Similarly, the leftmost bottom point has
+  // the same y value as the rightmost bottom point.
 
- // If the scope is vertical, then there is only one single point that has the
- // greatest y value. Likewise, there is only one single point having the
- // smallest y value. Conversely, there are going to be two points of differing
- // y values having the same x value (2 leftmost points and two rightmost
- // points).
+  // If the scope is vertical, then there is only one single point that has the
+  // greatest y value. Likewise, there is only one single point having the
+  // smallest y value. Conversely, there are going to be two points of differing
+  // y values having the same x value (2 leftmost points and two rightmost
+  // points).
 
- std::vector<QPointF> points;
+  std::vector<QPointF> points;
 
- // First get the top most point, we'll use the y value to check if there is
- // only one point sharing that value or not.
+  // First get the top most point, we'll use the y value to check if there is
+  // only one point sharing that value or not.
 
- // qDebug() << "The rhomboid integration scope:" << toString();
+  // qDebug() << "The rhomboid integration scope:" << toString();
 
- IntegrationScopeFeatures scope_features = getTopMostPoints(points);
+  IntegrationScopeFeatures scope_features = getTopMostPoints(points);
 
- if(scope_features == IntegrationScopeFeatures::FAILURE)
-  qFatal("Failed to get top most points.");
+  if(scope_features == IntegrationScopeFeatures::FAILURE)
+    qFatal("Failed to get top most points.");
 
- // qDebug() << "getTopMostPoints() got" << points.size() << "points.";
+  // qDebug() << "getTopMostPoints() got" << points.size() << "points.";
 
- if(scope_features & IntegrationScopeFeatures::FLAT_ON_X_AXIS)
- {
-  // Do not change anything to the width passed as parameter.
- }
- else if(scope_features & IntegrationScopeFeatures::RHOMBOID_HORIZONTAL)
- {
-  // We are dealing with a horizontal rhomboid. Thus we *must* have
-  // gotten 2 points.
-  size = fabs(points.at(0).x() - points.at(1).x());
- }
- else if(scope_features &
-  IntegrationScopeFeatures::RHOMBOID_VERTICAL)
- {
-  // We are dealing with a vertical rhomboid.
-  size = 0;
- }
+  if(scope_features & IntegrationScopeFeatures::FLAT_ON_X_AXIS)
+    {
+      // Do not change anything to the width passed as parameter.
+    }
+  else if(scope_features & IntegrationScopeFeatures::RHOMBOID_HORIZONTAL)
+    {
+      // We are dealing with a horizontal rhomboid. Thus we *must* have
+      // gotten 2 points.
+      size = fabs(points.at(0).x() - points.at(1).x());
+    }
+  else if(scope_features & IntegrationScopeFeatures::RHOMBOID_VERTICAL)
+    {
+      // We are dealing with a vertical rhomboid.
+      size = 0;
+    }
 
- return scope_features;
+  return scope_features;
 }
 
 IntegrationScopeFeatures
 IntegrationScopeRhomb::getRhombVerticalSize(double &size) const
 {
- // See getRhombHorizontalSize() for explanations.
+  // See getRhombHorizontalSize() for explanations.
 
- // If the scope is horizontal, then two points of same y value (either top or
- // bottom) have different x values. That is, leftmost top point has the same y
- // value as the rightmost top point. Similarly, the leftmost bottom point has
- // the same y value as the rightmost bottom point.
+  // If the scope is horizontal, then two points of same y value (either top or
+  // bottom) have different x values. That is, leftmost top point has the same y
+  // value as the rightmost top point. Similarly, the leftmost bottom point has
+  // the same y value as the rightmost bottom point.
 
- // If the scope is vertical, then there is only one single point that has the
- // greatest y value. Likewise, there is only one single point having the
- // smallest y value. Conversely, there are going to be two points of differing
- // y values having the same x value (2 leftmost points and two rightmost
- // points).
+  // If the scope is vertical, then there is only one single point that has the
+  // greatest y value. Likewise, there is only one single point having the
+  // smallest y value. Conversely, there are going to be two points of differing
+  // y values having the same x value (2 leftmost points and two rightmost
+  // points).
 
- std::vector<QPointF> points;
+  std::vector<QPointF> points;
 
- // Get the leftmost points (there are going to be 1 or 2 points in the
- // vector depending on the kind of rhomboid.
+  // Get the leftmost points (there are going to be 1 or 2 points in the
+  // vector depending on the kind of rhomboid.
 
- // qDebug() << "The rhomboid integration scope:" << toString();
+  // qDebug() << "The rhomboid integration scope:" << toString();
 
- IntegrationScopeFeatures scope_features = getLeftMostPoints(points);
+  IntegrationScopeFeatures scope_features = getLeftMostPoints(points);
 
- if(scope_features == IntegrationScopeFeatures::FAILURE)
-  qFatal("Failed to get left most points.");
+  if(scope_features == IntegrationScopeFeatures::FAILURE)
+    qFatal("Failed to get left most points.");
 
- // qDebug() << "getLeftMostPoints() got" << points.size() << "points.";
+  // qDebug() << "getLeftMostPoints() got" << points.size() << "points.";
 
- if(scope_features & IntegrationScopeFeatures::FLAT_ON_Y_AXIS)
- {
-  // Do not change anything to the width passed as parameter.
- }
- else if(scope_features & IntegrationScopeFeatures::RHOMBOID_HORIZONTAL)
- {
-  // We are dealing with a horizontal rhomboid.
-  size = 0;
- }
- else if(scope_features & IntegrationScopeFeatures::RHOMBOID_VERTICAL)
- {
-  // We are dealing with a vertical rhomboid. Thus we *must* have
-  // gotten 2 points.
-  size = fabs(points.at(0).y() - points.at(1).y());
- }
+  if(scope_features & IntegrationScopeFeatures::FLAT_ON_Y_AXIS)
+    {
+      // Do not change anything to the width passed as parameter.
+    }
+  else if(scope_features & IntegrationScopeFeatures::RHOMBOID_HORIZONTAL)
+    {
+      // We are dealing with a horizontal rhomboid.
+      size = 0;
+    }
+  else if(scope_features & IntegrationScopeFeatures::RHOMBOID_VERTICAL)
+    {
+      // We are dealing with a vertical rhomboid. Thus we *must* have
+      // gotten 2 points.
+      size = fabs(points.at(0).y() - points.at(1).y());
+    }
 
- return scope_features;
+  return scope_features;
 }
 
 bool
@@ -908,8 +903,7 @@ IntegrationScopeRhomb::range(Enums::Axis axis, double &start, double &end) const
         qFatal("Failed to get left-most point.");
 
       QPointF right_most_point;
-      if(getRightMostPoint(right_most_point) ==
-         IntegrationScopeFeatures::FAILURE)
+      if(getRightMostPoint(right_most_point) == IntegrationScopeFeatures::FAILURE)
         qFatal("Failed to get right-most point.");
 
       start = left_most_point.x();
@@ -920,8 +914,7 @@ IntegrationScopeRhomb::range(Enums::Axis axis, double &start, double &end) const
   else if(axis == Enums::Axis::y)
     {
       QPointF bottom_most_point;
-      if(getBottomMostPoint(bottom_most_point) ==
-         IntegrationScopeFeatures::FAILURE)
+      if(getBottomMostPoint(bottom_most_point) == IntegrationScopeFeatures::FAILURE)
         qFatal("Failed to get bottom-most point.");
 
       QPointF top_most_point;
@@ -991,8 +984,8 @@ bool
 IntegrationScopeRhomb::transpose()
 {
   Enums::DataKind was_data_kind_y = m_dataKindY;
-  m_dataKindY              = m_dataKindX;
-  m_dataKindX              = was_data_kind_y;
+  m_dataKindY                     = m_dataKindX;
+  m_dataKindX                     = was_data_kind_y;
 
   // Transpose each point in a new vector.
   std::vector<QPointF> transposed_points;
@@ -1025,10 +1018,8 @@ IntegrationScopeRhomb::contains(const QPointF &point) const
 
   for(i = 0, j = vertex_count - 1; i < vertex_count; j = i++)
     {
-      if(((m_points.at(i).y() > point.y()) !=
-          (m_points.at(j).y() > point.y())) &&
-         (point.x() < (m_points.at(j).x() - m_points.at(i).x()) *
-                          (point.y() - m_points.at(i).y()) /
+      if(((m_points.at(i).y() > point.y()) != (m_points.at(j).y() > point.y())) &&
+         (point.x() < (m_points.at(j).x() - m_points.at(i).x()) * (point.y() - m_points.at(i).y()) /
                           (m_points.at(j).y() - m_points.at(i).y()) +
                         m_points.at(i).x()))
         is_inside = !is_inside;
