@@ -20,16 +20,15 @@ namespace pappso
 
 SelectionPolygon::SelectionPolygon()
 {
-  // When we create a polygon, we create it as immense as possible, so that 
- // if this polygon is not modified, any other polygon created on the basis
- // of experimental data will fit inside it.
- 
- // See the definition of the points in the header file.
+  // When we create a polygon, we create it as immense as possible, so that
+  // if this polygon is not modified, any other polygon created on the basis
+  // of experimental data will fit inside it.
+
+  // See the definition of the points in the header file.
 }
 
 
-SelectionPolygon::SelectionPolygon(QPointF top_left_point,
-                                   QPointF top_right_point)
+SelectionPolygon::SelectionPolygon(QPointF top_left_point, QPointF top_right_point)
 {
   // First clear the default values points because we want to push_back
   // new points and we want to only ever have 4 points.
@@ -42,24 +41,20 @@ SelectionPolygon::SelectionPolygon(QPointF top_left_point,
   // that specified x range and
   //
   // the widest y range possible.
-  
+
   // In other words, we are crafting a 1D selection polygon.
 
   // top left point
-  m_points.push_back(
-    QPointF(top_left_point.x(), std::numeric_limits<double>::max()));
+  m_points.push_back(QPointF(top_left_point.x(), std::numeric_limits<double>::max()));
 
   // top right point
-  m_points.push_back(
-    QPointF(top_right_point.x(), std::numeric_limits<double>::max()));
+  m_points.push_back(QPointF(top_right_point.x(), std::numeric_limits<double>::max()));
 
   // bottom right point
-  m_points.push_back(
-    QPointF(top_right_point.x(), std::numeric_limits<double>::min()));
+  m_points.push_back(QPointF(top_right_point.x(), std::numeric_limits<double>::min()));
 
   // bottom left point
-  m_points.push_back(
-    QPointF(top_left_point.x(), std::numeric_limits<double>::min()));
+  m_points.push_back(QPointF(top_left_point.x(), std::numeric_limits<double>::min()));
 
   // Compute the min|max x|y coordinates of the polygon that will be used to
   // quickly check if a point is outside.
@@ -91,8 +86,7 @@ SelectionPolygon::SelectionPolygon(QPointF top_left_point,
 SelectionPolygon::SelectionPolygon(const SelectionPolygon &other)
 {
   if(other.m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
-    qFatal(
-      "The template selection polygon must have four points, no less, no more");
+    qFatal("The template selection polygon must have four points, no less, no more");
 
   // First clear the default values points.
   m_points.clear();
@@ -135,8 +129,7 @@ SelectionPolygon::setPoint(PointSpec point_spec, QPointF point)
 
 
 void
-SelectionPolygon::copyPoint(PointSpec point_spec_src,
-                            PointSpec point_spec_dest)
+SelectionPolygon::copyPoint(PointSpec point_spec_src, PointSpec point_spec_dest)
 {
   QPointF src_point = getPoint(point_spec_src);
   setPoint(point_spec_dest, src_point);
@@ -159,16 +152,13 @@ SelectionPolygon::set1D(double x_range_start, double x_range_end)
   resetPoints();
 
   // top left point
-  setPoint(PointSpec::TOP_LEFT_POINT,
-           QPointF(x_range_start, std::numeric_limits<double>::max()));
+  setPoint(PointSpec::TOP_LEFT_POINT, QPointF(x_range_start, std::numeric_limits<double>::max()));
 
   // top right point
-  setPoint(PointSpec::TOP_RIGHT_POINT,
-           QPointF(x_range_end, std::numeric_limits<double>::max()));
+  setPoint(PointSpec::TOP_RIGHT_POINT, QPointF(x_range_end, std::numeric_limits<double>::max()));
 
   // bottom right point
-  setPoint(PointSpec::BOTTOM_RIGHT_POINT,
-           QPointF(x_range_end, std::numeric_limits<double>::min()));
+  setPoint(PointSpec::BOTTOM_RIGHT_POINT, QPointF(x_range_end, std::numeric_limits<double>::min()));
 
   // bottom left point
   setPoint(PointSpec::BOTTOM_LEFT_POINT,
@@ -462,24 +452,21 @@ SelectionPolygon::transpose() const
   // position in the polygon corners. Of course, x becomes y.
   selection_polygon.setPoint(
     PointSpec::TOP_RIGHT_POINT,
-    QPointF(getPoint(PointSpec::TOP_RIGHT_POINT).y(),
-            getPoint(PointSpec::TOP_RIGHT_POINT).x()));
+    QPointF(getPoint(PointSpec::TOP_RIGHT_POINT).y(), getPoint(PointSpec::TOP_RIGHT_POINT).x()));
 
-  selection_polygon.setPoint(
-    PointSpec::BOTTOM_LEFT_POINT,
-    QPointF(getPoint(PointSpec::BOTTOM_LEFT_POINT).y(),
-            getPoint(PointSpec::BOTTOM_LEFT_POINT).x()));
+  selection_polygon.setPoint(PointSpec::BOTTOM_LEFT_POINT,
+                             QPointF(getPoint(PointSpec::BOTTOM_LEFT_POINT).y(),
+                                     getPoint(PointSpec::BOTTOM_LEFT_POINT).x()));
 
   // The two other points.
 
-  selection_polygon.setPoint(PointSpec::BOTTOM_RIGHT_POINT,
-                             QPointF(getPoint(PointSpec::TOP_LEFT_POINT).y(),
-                                     getPoint(PointSpec::TOP_LEFT_POINT).x()));
-
   selection_polygon.setPoint(
-    PointSpec::TOP_LEFT_POINT,
-    QPointF(getPoint(PointSpec::BOTTOM_RIGHT_POINT).y(),
-            getPoint(PointSpec::BOTTOM_RIGHT_POINT).x()));
+    PointSpec::BOTTOM_RIGHT_POINT,
+    QPointF(getPoint(PointSpec::TOP_LEFT_POINT).y(), getPoint(PointSpec::TOP_LEFT_POINT).x()));
+
+  selection_polygon.setPoint(PointSpec::TOP_LEFT_POINT,
+                             QPointF(getPoint(PointSpec::BOTTOM_RIGHT_POINT).y(),
+                                     getPoint(PointSpec::BOTTOM_RIGHT_POINT).x()));
 
   return selection_polygon;
 }
@@ -491,8 +478,8 @@ SelectionPolygon::contains(const QPointF &tested_point) const
   // Easy check: if the point lies outside of most external limits of the
   // polygon, return false.
 
-  if(tested_point.x() < m_minX || tested_point.x() > m_maxX ||
-     tested_point.y() < m_minY || tested_point.y() > m_maxY)
+  if(tested_point.x() < m_minX || tested_point.x() > m_maxX || tested_point.y() < m_minY ||
+     tested_point.y() > m_maxY)
     {
       // qDebug() << "Testing point:" << tested_point
       //<< "aginst polygon:" << toString()
@@ -550,8 +537,7 @@ SelectionPolygon::contains(const QPointF &tested_point) const
 
   for(i = 0, j = vertex_count - 1; i < vertex_count; j = i++)
     {
-      if(((m_points.at(i).y() > tested_point.y()) !=
-          (m_points.at(j).y() > tested_point.y())) &&
+      if(((m_points.at(i).y() > tested_point.y()) != (m_points.at(j).y() > tested_point.y())) &&
          (tested_point.x() < (m_points.at(j).x() - m_points.at(i).x()) *
                                  (tested_point.y() - m_points.at(i).y()) /
                                  (m_points.at(j).y() - m_points.at(i).y()) +
@@ -619,14 +605,10 @@ SelectionPolygon::resetPoints()
   // Reset the points exactly as they were set upon construction of an empty
   // polygon.
 
-  m_points[0] = QPointF(std::numeric_limits<double>::min(),
-                        std::numeric_limits<double>::max());
-  m_points[0] = QPointF(std::numeric_limits<double>::max(),
-                        std::numeric_limits<double>::max());
-  m_points[0] = QPointF(std::numeric_limits<double>::max(),
-                        std::numeric_limits<double>::min());
-  m_points[0] = QPointF(std::numeric_limits<double>::min(),
-                        std::numeric_limits<double>::max());
+  m_points[0] = QPointF(std::numeric_limits<double>::min(), std::numeric_limits<double>::max());
+  m_points[0] = QPointF(std::numeric_limits<double>::max(), std::numeric_limits<double>::max());
+  m_points[0] = QPointF(std::numeric_limits<double>::max(), std::numeric_limits<double>::min());
+  m_points[0] = QPointF(std::numeric_limits<double>::min(), std::numeric_limits<double>::max());
 }
 
 
@@ -650,12 +632,10 @@ SelectionPolygon::is1D() const
 
   // A polygon is mono-dimensional if it has both non-0 width and no (max-min)
   // width AND if the height is 0 or (max-min).
-  return (
-    (width_value > 0 && width_value < std::numeric_limits<double>::max() -
-                                        std::numeric_limits<double>::min()) &&
-    (height_value == 0 ||
-     height_value == std::numeric_limits<double>::max() -
-                       std::numeric_limits<double>::min()));
+  return ((width_value > 0 &&
+           width_value < std::numeric_limits<double>::max() - std::numeric_limits<double>::min()) &&
+          (height_value == 0 || height_value == std::numeric_limits<double>::max() -
+                                                  std::numeric_limits<double>::min()));
 }
 
 
@@ -677,11 +657,10 @@ SelectionPolygon::is2D() const
 
   // A polygon is two-dimensional if it has both non-0 width and no (max-min)
   // width AND same for height.
-  return (
-    (width_value > 0 && width_value < std::numeric_limits<double>::max() -
-                                        std::numeric_limits<double>::min()) &&
-    (height_value > 0 && height_value < std::numeric_limits<double>::max() -
-                                          std::numeric_limits<double>::min()));
+  return ((width_value > 0 &&
+           width_value < std::numeric_limits<double>::max() - std::numeric_limits<double>::min()) &&
+          (height_value > 0 &&
+           height_value < std::numeric_limits<double>::max() - std::numeric_limits<double>::min()));
 }
 
 
@@ -704,19 +683,15 @@ SelectionPolygon::isRectangle() const
 
   // Try the horiontal top|bottom lines.
 
-  if(getPoint(PointSpec::TOP_LEFT_POINT).y() ==
-       getPoint(PointSpec::TOP_RIGHT_POINT).y() &&
-     getPoint(PointSpec::BOTTOM_LEFT_POINT).y() ==
-       getPoint(PointSpec::BOTTOM_RIGHT_POINT).y())
+  if(getPoint(PointSpec::TOP_LEFT_POINT).y() == getPoint(PointSpec::TOP_RIGHT_POINT).y() &&
+     getPoint(PointSpec::BOTTOM_LEFT_POINT).y() == getPoint(PointSpec::BOTTOM_RIGHT_POINT).y())
     {
       // We have horizontal top|bottom lines
 
       // Try the vertical lines
 
-      if(getPoint(PointSpec::TOP_LEFT_POINT).x() ==
-           getPoint(PointSpec::BOTTOM_LEFT_POINT).x() &&
-         getPoint(PointSpec::TOP_RIGHT_POINT).x() ==
-           getPoint(PointSpec::BOTTOM_RIGHT_POINT).x())
+      if(getPoint(PointSpec::TOP_LEFT_POINT).x() == getPoint(PointSpec::BOTTOM_LEFT_POINT).x() &&
+         getPoint(PointSpec::TOP_RIGHT_POINT).x() == getPoint(PointSpec::BOTTOM_RIGHT_POINT).x())
         {
           // The top|bottom lines are vertical
 
@@ -759,26 +734,22 @@ SelectionPolygon::toString() const
       text += QString("(%1,%2)\n").arg(x_string).arg(y_string);
     }
 
-  if(m_minX != std::numeric_limits<double>::min() &&
-     m_minX != std::numeric_limits<double>::max())
+  if(m_minX != std::numeric_limits<double>::min() && m_minX != std::numeric_limits<double>::max())
     text += QString("minX: %1 - ").arg(m_minX, 0, 'f', 10);
   else
     text += QString("minX: NOT_SET - ");
 
-  if(m_maxX != std::numeric_limits<double>::min() &&
-     m_maxX != std::numeric_limits<double>::max())
+  if(m_maxX != std::numeric_limits<double>::min() && m_maxX != std::numeric_limits<double>::max())
     text += QString("maxX: %1 - ").arg(m_maxX, 0, 'f', 10);
   else
     text += QString("maxX: NOT_SET - ");
 
-  if(m_minY != std::numeric_limits<double>::min() &&
-     m_minY != std::numeric_limits<double>::max())
+  if(m_minY != std::numeric_limits<double>::min() && m_minY != std::numeric_limits<double>::max())
     text += QString("minY: %1 - ").arg(m_minY, 0, 'f', 10);
   else
     text += QString("minY: NOT_SET - ");
 
-  if(m_maxY != std::numeric_limits<double>::min() &&
-     m_maxY != std::numeric_limits<double>::max())
+  if(m_maxY != std::numeric_limits<double>::min() && m_maxY != std::numeric_limits<double>::max())
     text += QString("maxY: %1 - ").arg(m_maxY, 0, 'f', 10);
   else
     text += QString("maxY: NOT_SET - ");
