@@ -23,8 +23,7 @@ TraceCombiner::TraceCombiner()
 }
 
 
-TraceCombiner::TraceCombiner(int decimal_places)
-  : MassDataCombinerInterface(decimal_places)
+TraceCombiner::TraceCombiner(int decimal_places) : MassDataCombinerInterface(decimal_places)
 {
 }
 
