@@ -56,8 +56,7 @@ FilterSavitzkyGolay::FilterSavitzkyGolay()
   // m_params will have defaults that work well with mass spectra.
 }
 
-FilterSavitzkyGolay::FilterSavitzkyGolay(
-  int nL, int nR, int m, int lD, bool convolveWithNr)
+FilterSavitzkyGolay::FilterSavitzkyGolay(int nL, int nR, int m, int lD, bool convolveWithNr)
 {
   m_params.nL             = nL;
   m_params.nR             = nR;
@@ -134,8 +133,7 @@ FilterSavitzkyGolay::buildFilterFromString(const QString &parameters)
   else
     {
       throw pappso::ExceptionNotRecognized(
-        QString("Building of FilterSavitzkyGolay from string %1 failed")
-          .arg(parameters));
+        QString("Building of FilterSavitzkyGolay from string '%1' failed").arg(parameters));
     }
 }
 
@@ -183,8 +181,7 @@ FilterSavitzkyGolay::filter(Trace &data_points) const
 SavGolParams
 FilterSavitzkyGolay::getParameters() const
 {
-  return SavGolParams(
-    m_params.nL, m_params.nR, m_params.m, m_params.lD, m_params.convolveWithNr);
+  return SavGolParams(m_params.nL, m_params.nR, m_params.m, m_params.lD, m_params.convolveWithNr);
 }
 
 
@@ -244,8 +241,7 @@ FilterSavitzkyGolay::dmatrix(long nrl, long nrh, long ncl, long nch) const
     }
   m += 1;
   m -= nrl;
-  m[nrl] = (pappso_double *)malloc(
-    (size_t)((nrow * ncol + 1) * sizeof(pappso_double)));
+  m[nrl] = (pappso_double *)malloc((size_t)((nrow * ncol + 1) * sizeof(pappso_double)));
   if(!m[nrl])
     {
       qFatal("Error: Allocation failure.");
@@ -259,29 +255,22 @@ FilterSavitzkyGolay::dmatrix(long nrl, long nrh, long ncl, long nch) const
 
 
 void
-FilterSavitzkyGolay::free_ivector(int *v,
-                                  long nl,
-                                  [[maybe_unused]] long nh) const
+FilterSavitzkyGolay::free_ivector(int *v, long nl, [[maybe_unused]] long nh) const
 {
   free((char *)(v + nl - 1));
 }
 
 
 void
-FilterSavitzkyGolay::free_dvector(pappso_double *v,
-                                  long nl,
-                                  [[maybe_unused]] long nh) const
+FilterSavitzkyGolay::free_dvector(pappso_double *v, long nl, [[maybe_unused]] long nh) const
 {
   free((char *)(v + nl - 1));
 }
 
 
 void
-FilterSavitzkyGolay::free_dmatrix(pappso_double **m,
-                                  long nrl,
-                                  [[maybe_unused]] long nrh,
-                                  long ncl,
-                                  [[maybe_unused]] long nch) const
+FilterSavitzkyGolay::free_dmatrix(
+  pappso_double **m, long nrl, [[maybe_unused]] long nrh, long ncl, [[maybe_unused]] long nch) const
 {
   free((char *)(m[nrl] + ncl - 1));
   free((char *)(m + nrl - 1));
@@ -289,10 +278,7 @@ FilterSavitzkyGolay::free_dmatrix(pappso_double **m,
 
 
 void
-FilterSavitzkyGolay::lubksb(pappso_double **a,
-                            int n,
-                            int *indx,
-                            pappso_double b[]) const
+FilterSavitzkyGolay::lubksb(pappso_double **a, int n, int *indx, pappso_double b[]) const
 {
   int i, ii = 0, ip, j;
   pappso_double sum;
@@ -320,10 +306,7 @@ FilterSavitzkyGolay::lubksb(pappso_double **a,
 
 
 void
-FilterSavitzkyGolay::ludcmp(pappso_double **a,
-                            int n,
-                            int *indx,
-                            pappso_double *d) const
+FilterSavitzkyGolay::ludcmp(pappso_double **a, int n, int *indx, pappso_double *d) const
 {
   int i, imax = 0, j, k;
   pappso_double big, dum, sum, temp;
@@ -555,9 +538,8 @@ FilterSavitzkyGolay::convlv(pappso_double data[],
     {
       if(isign == 1)
         {
-          ans[i - 1] =
-            (fft[i - 1] * (dum = ans[i - 1]) - fft[i] * ans[i]) / no2;
-          ans[i] = (fft[i] * dum + fft[i - 1] * ans[i]) / no2;
+          ans[i - 1] = (fft[i - 1] * (dum = ans[i - 1]) - fft[i] * ans[i]) / no2;
+          ans[i]     = (fft[i] * dum + fft[i - 1] * ans[i]) / no2;
         }
       else if(isign == -1)
         {
@@ -566,9 +548,8 @@ FilterSavitzkyGolay::convlv(pappso_double data[],
               qDebug("Attempt of deconvolving at zero response in convlv().");
               return (1);
             }
-          ans[i - 1] =
-            (fft[i - 1] * (dum = ans[i - 1]) + fft[i] * ans[i]) / mag2 / no2;
-          ans[i] = (fft[i] * dum - fft[i - 1] * ans[i]) / mag2 / no2;
+          ans[i - 1] = (fft[i - 1] * (dum = ans[i - 1]) + fft[i] * ans[i]) / mag2 / no2;
+          ans[i]     = (fft[i] * dum - fft[i - 1] * ans[i]) / mag2 / no2;
         }
       else
         {
@@ -584,8 +565,7 @@ FilterSavitzkyGolay::convlv(pappso_double data[],
 
 
 char
-FilterSavitzkyGolay::sgcoeff(
-  pappso_double c[], int np, int nl, int nr, int ld, int m) const
+FilterSavitzkyGolay::sgcoeff(pappso_double c[], int np, int nl, int nr, int ld, int m) const
 {
   int imj, ipj, j, k, kk, mm, *indx;
   pappso_double d, fac, sum, **a, *b;
@@ -664,37 +644,31 @@ FilterSavitzkyGolay::runFilter(double *y_data_p,
 
       for(k = 1; k <= m_params.nL; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
-              j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR; j++)
             {
               if(k + j >= 1)
                 {
                   y_filtered_data_p[k] +=
-                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
-                    y_data_p[k + j];
+                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] * y_data_p[k + j];
                 }
             }
         }
       for(k = m_params.nL + 1; k <= data_point_count - m_params.nR; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
-              j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR; j++)
             {
               y_filtered_data_p[k] +=
-                c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
-                y_data_p[k + j];
+                c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] * y_data_p[k + j];
             }
         }
       for(k = data_point_count - m_params.nR + 1; k <= data_point_count; k++)
         {
-          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR;
-              j++)
+          for(y_filtered_data_p[k] = 0.0, j = -m_params.nL; j <= m_params.nR; j++)
             {
               if(k + j <= data_point_count)
                 {
                   y_filtered_data_p[k] +=
-                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] *
-                    y_data_p[k + j];
+                    c[(j >= 0 ? j + 1 : m_params.nR + m_params.nL + 2 + j)] * y_data_p[k + j];
                 }
             }
         }
