@@ -44,8 +44,7 @@ namespace pappso
 {
 namespace specglob
 {
-SpectralAlignment::SpectralAlignment(ScoreValues score_values,
-                                     pappso::PrecisionPtr precision_ptr)
+SpectralAlignment::SpectralAlignment(ScoreValues score_values, pappso::PrecisionPtr precision_ptr)
 {
   m_precisionPtr = precision_ptr;
   m_scoreValues  = score_values;
@@ -74,14 +73,12 @@ SpectralAlignment::align(PeptideSpectraCsp peptide_spectrum,
   mcsp_experimentalSpectrum = experimental_spectrum;
   mcsp_peptideSpectrum      = peptide_spectrum;
   m_maxScore                = 0;
-  m_matrix.resize(mcsp_peptideSpectrum.get()->size(),
-                  mcsp_experimentalSpectrum.get()->size());
+  m_matrix.resize(mcsp_peptideSpectrum.get()->size(), mcsp_experimentalSpectrum.get()->size());
 
   // set the value of difference between Precursor mass and theoretical mass of
   // the proposed peptide
-  m_precursorMassDelta =
-    mcsp_experimentalSpectrum.get()->getPrecursorMass() -
-    mcsp_peptideSpectrum.get()->getPeptideSp().get()->getMass();
+  m_precursorMassDelta = mcsp_experimentalSpectrum.get()->getPrecursorMass() -
+                         mcsp_peptideSpectrum.get()->getPeptideSp().get()->getMass();
 
   fillMassDelta(*mcsp_peptideSpectrum.get(), *mcsp_experimentalSpectrum.get());
 
@@ -94,9 +91,8 @@ SpectralAlignment::align(PeptideSpectraCsp peptide_spectrum,
       for(auto itmj = ++itmi.begin(); itmj != itmi.end(); itmj++)
         {
           // qDebug() << "i=" << itmj.index1() << " j=" << itmj.index2();
-          fillMatricesWithScores(itmj,
-                                 *mcsp_peptideSpectrum.get(),
-                                 *mcsp_experimentalSpectrum.get());
+          fillMatricesWithScores(
+            itmj, *mcsp_peptideSpectrum.get(), *mcsp_experimentalSpectrum.get());
           // keep the Max Score during matrixes filling
           // the condition is to keep the max score in the last line (last
           // theoretical amino acid) This is for try to keep all amino acids of
@@ -128,8 +124,8 @@ SpectralAlignment::rtrim(PrecisionPtr precision_ptr)
       std::size_t length = peptide_sp.get()->size();
       while(peptide_sp.get()->getMass() > (precursor_mass * 1.1))
         {
-          peptide_sp = std::make_shared<pappso::Peptide>(
-            peptide_sp.get()->getSequence().mid(0, length - 1));
+          peptide_sp =
+            std::make_shared<pappso::Peptide>(peptide_sp.get()->getSequence().mid(0, length - 1));
           if(length > 1)
             length--;
         }
@@ -156,8 +152,7 @@ SpectralAlignment::rtrim(PrecisionPtr precision_ptr)
 
 void
 SpectralAlignment::fillMatricesWithScores(
-  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2
-    &it_pos,
+  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2 &it_pos,
   const PeptideSpectrum &peptide_spectrum,
   const ExperimentalSpectrum &experimental_spectrum)
 {
@@ -165,58 +160,46 @@ SpectralAlignment::fillMatricesWithScores(
   // long expeIndiceJ = it_pos.index2();
   //  in first time, we set score corresponding to type of peak (initial/mirror
   //  or both) we set initial score to peak mirror or initial
-  ExperimentalSpectrumDataPointType expePeakType =
-    getExperimentalSpectrumDataPoint(it_pos).type;
+  ExperimentalSpectrumDataPointType expePeakType = getExperimentalSpectrumDataPoint(it_pos).type;
   //  experimental_spectrum.at(expeIndiceJ).type;
 
-  int alignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreAlignNative);
-  int reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignNative);
-  int reAlignScoreNOToAdd =
-    m_scoreValues.get(ScoreValueType::scoreReAlignNativeNO);
+  int alignScoreToAdd     = m_scoreValues.get(ScoreValueType::scoreAlignNative);
+  int reAlignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreReAlignNative);
+  int reAlignScoreNOToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignNativeNO);
 
   switch(expePeakType)
     {
       case ExperimentalSpectrumDataPointType::symmetric:
         // this is a symmetric peak
-        alignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreAlignSym);
-        reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignSym);
-        reAlignScoreNOToAdd =
-          m_scoreValues.get(ScoreValueType::scoreReAlignSymNO);
-        if(m_BETTER_END_RA &&
-           it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
+        alignScoreToAdd     = m_scoreValues.get(ScoreValueType::scoreAlignSym);
+        reAlignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreReAlignSym);
+        reAlignScoreNOToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignSymNO);
+        if(m_BETTER_END_RA && it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
           {
-            reAlignScoreToAdd =
-              m_scoreValues.get(ScoreValueType::scoreNonAlign) +
-              m_scoreValues.get(ScoreValueType::scoreAlignSym);
+            reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreNonAlign) +
+                                m_scoreValues.get(ScoreValueType::scoreAlignSym);
           }
         break;
       case ExperimentalSpectrumDataPointType::both:
         // this is a native peak with a symmetric corresponding
-        alignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreAlignBoth);
-        reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignBoth);
-        reAlignScoreNOToAdd =
-          m_scoreValues.get(ScoreValueType::scoreReAlignBothNO);
-        if(m_BETTER_END_RA &&
-           it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
+        alignScoreToAdd     = m_scoreValues.get(ScoreValueType::scoreAlignBoth);
+        reAlignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreReAlignBoth);
+        reAlignScoreNOToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignBothNO);
+        if(m_BETTER_END_RA && it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
           {
-            reAlignScoreToAdd =
-              m_scoreValues.get(ScoreValueType::scoreNonAlign) +
-              m_scoreValues.get(ScoreValueType::scoreAlignBoth);
+            reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreNonAlign) +
+                                m_scoreValues.get(ScoreValueType::scoreAlignBoth);
           }
         break;
       default:
         // this is a native or synthetic peak
-        alignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreAlignNative);
-        reAlignScoreToAdd =
-          m_scoreValues.get(ScoreValueType::scoreReAlignNative);
-        reAlignScoreNOToAdd =
-          m_scoreValues.get(ScoreValueType::scoreReAlignNativeNO);
-        if(m_BETTER_END_RA &&
-           it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
+        alignScoreToAdd     = m_scoreValues.get(ScoreValueType::scoreAlignNative);
+        reAlignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreReAlignNative);
+        reAlignScoreNOToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignNativeNO);
+        if(m_BETTER_END_RA && it_pos.index1() == peptide_spectrum.getPeptideSp().get()->size())
           {
-            reAlignScoreToAdd =
-              m_scoreValues.get(ScoreValueType::scoreNonAlign) +
-              m_scoreValues.get(ScoreValueType::scoreAlignNative);
+            reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreNonAlign) +
+                                m_scoreValues.get(ScoreValueType::scoreAlignNative);
           }
         break;
     }
@@ -231,22 +214,19 @@ SpectralAlignment::fillMatricesWithScores(
     qDebug() << "position1" << it_pos.index1() << "position2" << it_pos.index1()
   << " k=" << k << " " << peptide_spectrum.at(it_pos.index1()).diff_mz;
   */
-  pappso::MzRange aaMassRange(peptide_spectrum.at(it_pos.index1()).diff_mz,
-                              m_precisionPtr);
+  pappso::MzRange aaMassRange(peptide_spectrum.at(it_pos.index1()).diff_mz, m_precisionPtr);
   qDebug();
   // long k = -1;
-  auto itKpeak =
-    experimental_spectrum.reverseFindDiffMz(it_pos.index2(), aaMassRange);
+  auto itKpeak = experimental_spectrum.reverseFindDiffMz(it_pos.index2(), aaMassRange);
   // if(itKpeak != experimental_spectrum.rend())
   // k = itKpeak->indice;
 
   if(itKpeak == experimental_spectrum.rend())
     {
-      matrix_data_point_i_j.score =
-        m_matrix(it_pos.index1() - 1, it_pos.index2()).score +
-        (m_scoreValues.get(ScoreValueType::scoreNonAlign));
+      matrix_data_point_i_j.score = m_matrix(it_pos.index1() - 1, it_pos.index2()).score +
+                                    (m_scoreValues.get(ScoreValueType::scoreNonAlign));
       matrix_data_point_i_j.origin_column_indices = it_pos.index2();
-      matrix_data_point_i_j.alignment_type = SpectralAlignmentType::nonAlign;
+      matrix_data_point_i_j.alignment_type        = SpectralAlignmentType::nonAlign;
     }
   else
     {
@@ -255,24 +235,22 @@ SpectralAlignment::fillMatricesWithScores(
       int scoreAlignK = matrix_data_point_previ_k.score + alignScoreToAdd;
       // if it come from non align, we must verify that there is no offset from
       // previous align
-      if(matrix_data_point_previ_k.alignment_type ==
-         SpectralAlignmentType::nonAlign)
+      if(matrix_data_point_previ_k.alignment_type == SpectralAlignmentType::nonAlign)
         {
           int l;
           for(l = it_pos.index1() - 1; l > 0; l--)
             {
-              if(m_matrix(l, itKpeak->indice).origin_column_indices !=
-                 itKpeak->indice)
+              if(m_matrix(l, itKpeak->indice).origin_column_indices != itKpeak->indice)
                 break;
             }
-          if(std::abs(m_matrix(l, itKpeak->indice).mass_difference -
-                      (*it_pos).mass_difference) > m_precisionPtr->getNominal())
+          if(std::abs(m_matrix(l, itKpeak->indice).mass_difference - (*it_pos).mass_difference) >
+             m_precisionPtr->getNominal())
             scoreAlignK = matrix_data_point_previ_k.score + reAlignScoreToAdd;
         }
 
       // int[0] = the j value m and int[1] = the score value
-      SpectralAlignmentDataPoint reAlignBestScore = getBestRealignScore(
-        it_pos, itKpeak->indice, reAlignScoreToAdd, reAlignScoreNOToAdd);
+      SpectralAlignmentDataPoint reAlignBestScore =
+        getBestRealignScore(it_pos, itKpeak->indice, reAlignScoreToAdd, reAlignScoreNOToAdd);
 
       // For debug to see value for any match
       // System.out.println("score k = " + scoreAlignK + " - score m = " +
@@ -284,7 +262,7 @@ SpectralAlignment::fillMatricesWithScores(
           // setMatricesData(theoIndiceI, expeIndiceJ, scoreAlignK, k, 2);
           matrix_data_point_i_j.score                 = scoreAlignK;
           matrix_data_point_i_j.origin_column_indices = itKpeak->indice;
-          matrix_data_point_i_j.alignment_type = SpectralAlignmentType::align;
+          matrix_data_point_i_j.alignment_type        = SpectralAlignmentType::align;
         }
       else
         {
@@ -302,8 +280,7 @@ SpectralAlignment::fillMatricesWithScores(
 
 SpectralAlignmentDataPoint
 SpectralAlignment::getBestRealignScore(
-  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2
-    &it_pos,
+  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2 &it_pos,
   std::size_t expeIndicesK,
   int reAlignScore,
   int alignScoreToAdd)
@@ -330,7 +307,7 @@ SpectralAlignment::getBestRealignScore(
 
   return_data_point.origin_column_indices = origin;
   return_data_point.score                 = bestScore + reAlignScore;
-  return_data_point.alignment_type = SpectralAlignmentType::reAlign; // [2] = 1;
+  return_data_point.alignment_type        = SpectralAlignmentType::reAlign; // [2] = 1;
 
   if(origin == -1)
     return return_data_point;
@@ -351,12 +328,10 @@ SpectralAlignment::getBestRealignScore(
   // realign) is null, we consider that to an alignment
   if((lastAlignIndiceI != (previous_peptide_row)) && (it_pos.index1() > 1) &&
      (std::abs(m_matrix(previous_peptide_row, expeIndicesK).mass_difference -
-               m_matrix(lastAlignIndiceI, origin).mass_difference) <
-      m_precisionPtr->getNominal()))
+               m_matrix(lastAlignIndiceI, origin).mass_difference) < m_precisionPtr->getNominal()))
     {
-      return_data_point.score = bestScore + alignScoreToAdd;
-      return_data_point.alignment_type =
-        SpectralAlignmentType::align; //[2] = 2;
+      return_data_point.score          = bestScore + alignScoreToAdd;
+      return_data_point.alignment_type = SpectralAlignmentType::align; //[2] = 2;
     }
 
   // we return the origin (value of m) and the associate calculated score and
@@ -366,15 +341,13 @@ SpectralAlignment::getBestRealignScore(
 
 
 void
-SpectralAlignment::fillMassDelta(
-  const PeptideSpectrum &peptide_spectrum,
-  const ExperimentalSpectrum &experimental_spectrum)
+SpectralAlignment::fillMassDelta(const PeptideSpectrum &peptide_spectrum,
+                                 const ExperimentalSpectrum &experimental_spectrum)
 {
 
   auto it_peptide  = peptide_spectrum.begin();
   auto it_spectrum = experimental_spectrum.begin();
-  for(auto itr1 = m_matrix.begin1(); itr1 != m_matrix.end1();
-      ++itr1, it_peptide++)
+  for(auto itr1 = m_matrix.begin1(); itr1 != m_matrix.end1(); ++itr1, it_peptide++)
     {
       it_spectrum = experimental_spectrum.begin();
       for(auto itr2 = itr1.begin(); itr2 != itr1.end(); itr2++, it_spectrum++)
@@ -384,7 +357,7 @@ SpectralAlignment::fillMassDelta(
             (*itr2).alignment_type = SpectralAlignmentType::nonAlign;
           (*itr2).origin_column_indices = 0;
           (*itr2).score                 = 0;
-          (*itr2).mass_difference = it_spectrum->peak_mz - it_peptide->mz;
+          (*itr2).mass_difference       = it_spectrum->peak_mz - it_peptide->mz;
           // qDebug() << " i=" << itr2.index1() << " j=" << itr2.index2()
           //         << " mass_difference=" << (*itr2).mass_difference;
         }
@@ -425,8 +398,7 @@ SpectralAlignment::getMaxPosIterator() const
 
 const ExperimentalSpectrumDataPoint &
 SpectralAlignment::getExperimentalSpectrumDataPoint(
-  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2
-    &itpos) const
+  const boost::numeric::ublas::matrix<SpectralAlignmentDataPoint>::iterator2 &itpos) const
 {
   return mcsp_experimentalSpectrum.get()->at(itpos.index2());
 }
@@ -445,10 +417,9 @@ SpectralAlignment::backTrack() const
     {
       throw pappso::PappsoException("no backtrack");
     }
-  QString pepModified = "";
-  QString theoSequence =
-    mcsp_peptideSpectrum.get()->getPeptideSp().get()->getSequence();
-  int actualI = m_itPosMax.index1();
+  QString pepModified  = "";
+  QString theoSequence = mcsp_peptideSpectrum.get()->getPeptideSp().get()->getSequence();
+  int actualI          = m_itPosMax.index1();
   int prevI;
   int actualJ = m_itPosMax.index2();
   int prevJ;
@@ -475,18 +446,15 @@ SpectralAlignment::backTrack() const
 
       // We checking first if last Amino acid are not aligned
 
-      if(m_matrix(actualI, actualJ).alignment_type ==
-         SpectralAlignmentType::nonAlign)
+      if(m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::nonAlign)
         {
           // System.out.println("I'm NON ALIGN");
           tempPepSeq = QString("[%1]").arg(theoSequence.at(actualI - 1));
 
-          while(m_matrix(prevI, prevJ).alignment_type ==
-                  SpectralAlignmentType::nonAlign &&
+          while(m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign &&
                 prevI > 0)
             {
-              tempPepSeq =
-                QString("[%1]").arg(theoSequence.at(prevI - 1)) + tempPepSeq;
+              tempPepSeq = QString("[%1]").arg(theoSequence.at(prevI - 1)) + tempPepSeq;
               prevI--;
             }
           // modifCount++;
@@ -509,22 +477,19 @@ SpectralAlignment::backTrack() const
           aminoAcid  = tempPepSeq;
 
           // we check if there is a deletion before the founded aminoAcid
-          if(prevI > 0 && m_matrix(prevI, prevJ).alignment_type ==
-                            SpectralAlignmentType::nonAlign)
+          if(prevI > 0 && m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign)
             {
 
               // modifCount++;
 
               // we continue to check if this is a deletion bloc to keep the
               // mass difference due to the deletion of the block
-              while(prevI > 0 && m_matrix(prevI, prevJ).alignment_type ==
-                                   SpectralAlignmentType::nonAlign)
+              while(prevI > 0 &&
+                    m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign)
                 {
 
-                  tempPepSeq = QString("[%1]").arg(theoSequence.at(prevI - 1)) +
-                               tempPepSeq;
-                  tempAA =
-                    QString("%1").arg(theoSequence.at(prevI - 1)) + tempAA;
+                  tempPepSeq = QString("[%1]").arg(theoSequence.at(prevI - 1)) + tempPepSeq;
+                  tempAA     = QString("%1").arg(theoSequence.at(prevI - 1)) + tempAA;
 
                   prevI--;
                   prevDelMass = m_matrix(prevI, prevJ).mass_difference;
@@ -535,15 +500,12 @@ SpectralAlignment::backTrack() const
                 }
 
               // check the mass delta to avoid showing a null mass delta
-              if(std::abs(actualDelMass - prevDelMass) >
-                 m_precisionPtr->getNominal())
+              if(std::abs(actualDelMass - prevDelMass) > m_precisionPtr->getNominal())
                 {
 
                   tempPepSeq = tempPepSeq.mid(0, tempPepSeq.length() - 1);
 
-                  tempPepSeq +=
-                    QString("[%1]").arg(actualDelMass - prevDelMass) +
-                    aminoAcid;
+                  tempPepSeq += QString("[%1]").arg(actualDelMass - prevDelMass) + aminoAcid;
                   totExplainMass += (actualDelMass - prevDelMass);
                   modifCount++;
                   qDebug() << "a2a1 tempPepSeq=" << tempPepSeq;
@@ -552,12 +514,10 @@ SpectralAlignment::backTrack() const
               // if there this is just a re-align, we need to indicate the mass
               // offset
             }
-          else if(m_matrix(actualI, actualJ).alignment_type ==
-                  SpectralAlignmentType::reAlign)
+          else if(m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::reAlign)
             {
 
-              tempPepSeq =
-                QString("[%1]").arg(actualDelMass - prevDelMass) + tempPepSeq;
+              tempPepSeq = QString("[%1]").arg(actualDelMass - prevDelMass) + tempPepSeq;
               modifCount++;
               totExplainMass += (actualDelMass - prevDelMass);
 
@@ -565,8 +525,7 @@ SpectralAlignment::backTrack() const
               // leak of Amino acid in OMS solution before
             }
           else if(actualI == 1 &&
-                  m_matrix(actualI, actualJ).alignment_type ==
-                    SpectralAlignmentType::align &&
+                  m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::align &&
                   (std::abs(actualDelMass) > m_precisionPtr->getNominal()))
             {
               tempPepSeq = QString("[%1]").arg(actualDelMass) + tempPepSeq;
@@ -585,9 +544,7 @@ SpectralAlignment::backTrack() const
 
   // setModificationNumber(modifCount);
 
-  return QString("%1_[%2]")
-    .arg(pepModified)
-    .arg(m_precursorMassDelta - totExplainMass);
+  return QString("%1_[%2]").arg(pepModified).arg(m_precursorMassDelta - totExplainMass);
 }
 
 
@@ -597,12 +554,10 @@ SpectralAlignment::buildPeptideModel() const
   if(m_maxScore < 1)
     {
       throw pappso::PappsoException(
-        QObject::tr("building peptide model failed m_maxScore == %1")
-          .arg(m_maxScore));
+        QObject::tr("building peptide model failed m_maxScore == %1").arg(m_maxScore));
     }
-  PeptideModel sg_peptide_model(
-    mcsp_experimentalSpectrum.get()->getQualifiedMassSpectrum(),
-    *(mcsp_peptideSpectrum.get()->getPeptideSp().get()));
+  PeptideModel sg_peptide_model(mcsp_experimentalSpectrum.get()->getQualifiedMassSpectrum(),
+                                *(mcsp_peptideSpectrum.get()->getPeptideSp().get()));
   int actualI = m_itPosMax.index1();
   int prevI;
   int actualJ = m_itPosMax.index2();
@@ -626,13 +581,11 @@ SpectralAlignment::buildPeptideModel() const
 
       // We checking first if last Amino acid are not aligned
 
-      if(m_matrix(actualI, actualJ).alignment_type ==
-         SpectralAlignmentType::nonAlign)
+      if(m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::nonAlign)
         {
           // System.out.println("I'm NON ALIGN");
 
-          while(m_matrix(prevI, prevJ).alignment_type ==
-                  SpectralAlignmentType::nonAlign &&
+          while(m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign &&
                 prevI > 0)
             {
               if(prevI > 0)
@@ -654,16 +607,15 @@ SpectralAlignment::buildPeptideModel() const
           // of alignment type, we can have a mass offset
 
           // we check if there is a deletion before the founded aminoAcid
-          if(prevI > 0 && m_matrix(prevI, prevJ).alignment_type ==
-                            SpectralAlignmentType::nonAlign)
+          if(prevI > 0 && m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign)
             {
 
               // modifCount++;
 
               // we continue to check if this is a deletion bloc to keep the
               // mass difference due to the deletion of the block
-              while(prevI > 0 && m_matrix(prevI, prevJ).alignment_type ==
-                                   SpectralAlignmentType::nonAlign)
+              while(prevI > 0 &&
+                    m_matrix(prevI, prevJ).alignment_type == SpectralAlignmentType::nonAlign)
                 {
 
 
@@ -678,47 +630,40 @@ SpectralAlignment::buildPeptideModel() const
                 }
 
               // check the mass delta to avoid showing a null mass delta
-              if(std::abs(actualDelMass - prevDelMass) >
-                 m_precisionPtr->getNominal())
+              if(std::abs(actualDelMass - prevDelMass) > m_precisionPtr->getNominal())
                 {
 
                   int mass_i = actualI - 1;
                   if(mass_i == 0)
                     {
-                      sg_peptide_model.setBeginMassDelta(actualDelMass -
-                                                         prevDelMass);
+                      sg_peptide_model.setBeginMassDelta(actualDelMass - prevDelMass);
                     }
                   else
                     {
-                      sg_peptide_model[mass_i - 1].mass_difference =
-                        actualDelMass - prevDelMass;
+                      sg_peptide_model[mass_i - 1].mass_difference = actualDelMass - prevDelMass;
                     }
                 }
 
               // if there this is just a re-align, we need to indicate the mass
               // offset
             }
-          else if(m_matrix(actualI, actualJ).alignment_type ==
-                  SpectralAlignmentType::reAlign)
+          else if(m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::reAlign)
             {
 
               int mass_i = actualI - 1;
               if(mass_i == 0)
                 {
-                  sg_peptide_model.setBeginMassDelta(actualDelMass -
-                                                     prevDelMass);
+                  sg_peptide_model.setBeginMassDelta(actualDelMass - prevDelMass);
                 }
               else
                 {
-                  sg_peptide_model[mass_i - 1].mass_difference =
-                    actualDelMass - prevDelMass;
+                  sg_peptide_model[mass_i - 1].mass_difference = actualDelMass - prevDelMass;
                 }
               // the fact when you align the first amino acid, but there is a
               // leak of Amino acid in OMS solution before
             }
           else if(actualI == 1 &&
-                  m_matrix(actualI, actualJ).alignment_type ==
-                    SpectralAlignmentType::align &&
+                  m_matrix(actualI, actualJ).alignment_type == SpectralAlignmentType::align &&
                   (std::abs(actualDelMass) > m_precisionPtr->getNominal()))
             {
               sg_peptide_model.setBeginMassDelta(actualDelMass);
