@@ -32,6 +32,7 @@
 
 #include "pappsomspp/core/types.h"
 #include "pappsomspp/core/amino_acid/aa.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
@@ -51,7 +52,7 @@ struct AminoAcidModel
 /**
  * @brief modelize peptide sequence to facilitate rendering in bracket or proforma
  */
-class PeptideModel : public std::vector<AminoAcidModel>
+class PMSPP_LIB_DECL PeptideModel : public std::vector<AminoAcidModel>
 {
   public:
   /**
