@@ -55,7 +55,7 @@ pappso::specpeptidoms::Scenario::saveOrigin(std::size_t current_row,
       m_origin_matrix.at(current_row).at(current_column) = {
         previous_row, previous_column, alignment_type};
     }
-  catch(const std::exception &stderr)
+  catch(const std::exception &error)
     {
       int max_column_size = 0;
       if(current_row < m_origin_matrix.size())
