@@ -19,12 +19,13 @@
 #pragma once
 
 #include "pappsomspp/core/processing/specpeptidoms/types.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
 namespace specpeptidoms
 {
-class ScoreValues
+class PMSPP_LIB_DECL ScoreValues
 {
   public:
   ScoreValues();
