@@ -38,6 +38,7 @@
 #include "scenario.h"
 #include "peptidemodel.h"
 #include "spomsprotein.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
@@ -52,7 +53,7 @@ struct KeyCell
   int tree_id;
 };
 
-struct Alignment
+struct PMSPP_LIB_DECL Alignment
 {
   /** @brief reinitialize to default score_values
    */
@@ -87,7 +88,7 @@ struct Alignment
     end           = 0; // Localization of the alignment's last amino acid in the peptide sequence
 };
 
-class SemiGlobalAlignment
+class PMSPP_LIB_DECL SemiGlobalAlignment
 {
   public:
   /**
@@ -242,7 +243,8 @@ class SemiGlobalAlignment
 
   /**
    * @brief indicates if a perfect shift is possible from the spectrum beginning to the provided
-   * peak.
+   * peak. Returns the perfect shift origin if the shift is possible, otherwise returns the current
+   * row.
    * @param sequence Reversed sequence of the protein being aligned
    * @param spectrum Spectrum being aligned
    * @param current_row row being processed (== index of the current AaPosition in sequence)
