@@ -20,6 +20,7 @@
 
 #include "pappsomspp/core/protein/protein.h"
 #include "pappsomspp/core/amino_acid/aacode.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
@@ -33,7 +34,7 @@ struct SpOMSAa
   double mass;
 };
 
-class SpOMSProtein : public std::vector<SpOMSAa>
+class PMSPP_LIB_DECL SpOMSProtein : public std::vector<SpOMSAa>
 {
   public:
   SpOMSProtein(const QString &description, const QString &sequence, const AaCode &aa_code);
