@@ -46,8 +46,7 @@ namespace pappso
 {
 
 
-TandemWrapperRun::TandemWrapperRun(const QString &tandem_binary,
-                                   const QString &tmp_dir)
+TandemWrapperRun::TandemWrapperRun(const QString &tandem_binary, const QString &tmp_dir)
 {
 
   setTandemBinaryPath(tandem_binary);
@@ -92,8 +91,7 @@ TandemWrapperRun::setTandemBinaryPath(const QString &tandem_binary_path)
   QSettings settings;
   if(m_tandemBinary.isEmpty())
     {
-      m_tandemBinary =
-        settings.value("path/tandem_binary", "/usr/bin/tandem").toString();
+      m_tandemBinary = settings.value("path/tandem_binary", "/usr/bin/tandem").toString();
     }
   // check for tandem executable
   m_tandemVersion = checkXtandemVersion(m_tandemBinary);
@@ -113,9 +111,8 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
     {
       // dir.path() returns the unique directory path
       throw pappso::PappsoException(
-        QObject::tr(
-          "X!Tandem software not found at %1.\nPlease check the X!Tandem "
-          "installation on your computer and set tandem.exe path.")
+        QObject::tr("X!Tandem software not found at %1.\nPlease check the X!Tandem "
+                    "installation on your computer and set tandem.exe path.")
           .arg(tandem_exe.absoluteFilePath()));
     }
   if(!tandem_exe.isReadable())
@@ -149,8 +146,7 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
   if(!xt_process->waitForStarted())
     {
       throw pappso::PappsoException(
-        QObject::tr("X!Tandem %1 process failed to start")
-          .arg(m_tandemVersion));
+        QObject::tr("X!Tandem %1 process failed to start").arg(m_tandemVersion));
     }
 
   while(xt_process->waitForReadyRead(1000))
@@ -169,13 +165,11 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
 
   // X! TANDEM Jackhammer TPP (2013.06.15.1 - LabKey, Insilicos, ISB)
 
-  QRegularExpression parse_version(
-    "(.*) TANDEM ([A-Z,a-z, ]+) \\(([^ ,^\\)]*)(.*)");
+  QRegularExpression parse_version("(.*) TANDEM ([A-Z,a-z, ]+) \\(([^ ,^\\)]*)(.*)");
   qDebug() << parse_version;
   // Pattern patt = Pattern.compile("X! TANDEM [A-Z]+ \\((.*)\\)",
   //			Pattern.CASE_INSENSITIVE);
-  QRegularExpressionMatch match_parse_version =
-    parse_version.match(result.constData());
+  QRegularExpressionMatch match_parse_version = parse_version.match(result.constData());
   if(match_parse_version.hasMatch())
     {
       version_return = QString("X!Tandem %1 %2")
@@ -195,10 +189,9 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
   if(Status != 0)
     {
       // != QProcess::NormalExit
-      throw pappso::PappsoException(
-        QObject::tr("error executing X!Tandem Status != 0 : %1 %2\n%3")
-          .arg(tandem_bin_path)
-          .arg(arguments.join(" ").arg(result.data())));
+      throw pappso::PappsoException(QObject::tr("error executing X!Tandem Status != 0 : %1 %2\n%3")
+                                      .arg(tandem_bin_path)
+                                      .arg(arguments.join(" ").arg(result.data())));
     }
   qDebug();
   return version_return;
@@ -220,8 +213,7 @@ TandemWrapperRun::readyReadStandardOutput()
       m_xtProcess->kill();
       delete m_xtProcess;
       m_xtProcess = nullptr;
-      throw pappso::ExceptionInterrupted(
-        QObject::tr("X!Tandem stopped by the user"));
+      throw pappso::ExceptionInterrupted(QObject::tr("X!Tandem stopped by the user"));
     }
 }
 
@@ -234,25 +226,21 @@ TandemWrapperRun::readyReadStandardError()
       m_xtProcess->kill();
       delete m_xtProcess;
       m_xtProcess = nullptr;
-      throw pappso::ExceptionInterrupted(
-        QObject::tr("X!Tandem stopped by the user"));
+      throw pappso::ExceptionInterrupted(QObject::tr("X!Tandem stopped by the user"));
     }
 }
 
 void
-TandemWrapperRun::writeFinalTandemOutput(
-  const QString &tmp_tandem_output,
-  const QString &final_tandem_output,
-  const QString &original_msdata_file_name)
+TandemWrapperRun::writeFinalTandemOutput(const QString &tmp_tandem_output,
+                                         const QString &final_tandem_output,
+                                         const QString &original_msdata_file_name)
 {
   mp_monitor->setStatus(QObject::tr("Rewriting X!Tandem XML result file"));
 
   WrapTandemResults wrap_output(final_tandem_output, original_msdata_file_name);
 
-  wrap_output.setInputParameters("spectrum, timstof MS2 filters",
-                                 getMs2FilterSuiteString());
-  wrap_output.setInputParameters("spectrum, mzFormat",
-                                 QString("%1").arg((int)m_mzFormat));
+  wrap_output.setInputParameters("spectrum, timstof MS2 filters", getMs2FilterSuiteString());
+  wrap_output.setInputParameters("spectrum, mzFormat", QString("%1").arg((int)m_mzFormat));
 
   if(m_convertMzDataUsingSpectrumIndex)
     {
@@ -264,9 +252,8 @@ TandemWrapperRun::writeFinalTandemOutput(
 
   if(m_conversionTime != 0)
     {
-      wrap_output.setInputParameters(
-        "timing, tandemwrapper conversion time (sec)",
-        QString("%1").arg(m_conversionTime / 1000));
+      wrap_output.setInputParameters("timing, tandemwrapper conversion time (sec)",
+                                     QString("%1").arg(m_conversionTime / 1000));
     }
 
   if(wrap_output.readFile(tmp_tandem_output))
@@ -274,10 +261,9 @@ TandemWrapperRun::writeFinalTandemOutput(
     }
   else
     {
-      throw pappso::PappsoException(
-        QObject::tr("Error reading %1 X!Tandem output file :\n %2")
-          .arg(tmp_tandem_output)
-          .arg(wrap_output.errorString()));
+      throw pappso::PappsoException(QObject::tr("Error reading %1 X!Tandem output file :\n %2")
+                                      .arg(tmp_tandem_output)
+                                      .arg(wrap_output.errorString()));
     }
 }
 
@@ -306,30 +292,26 @@ TandemWrapperRun::readTandemPresetFile(const QString &tandem_preset_file)
             {
               QThreadPool::globalInstance()->setMaxThreadCount(cpu_number);
 
-              qDebug() << " maxThreadCount="
-                       << QThreadPool::globalInstance()->maxThreadCount();
+              qDebug() << " maxThreadCount=" << QThreadPool::globalInstance()->maxThreadCount();
             }
         }
 
       QString ms2_filters_str = preset_handler.getMs2FiltersOptions();
       if(!ms2_filters_str.isEmpty())
         {
-          msp_ms2FilterSuiteString =
-            std::make_shared<pappso::FilterSuiteString>(ms2_filters_str);
+          msp_ms2FilterSuiteString = std::make_shared<pappso::FilterSuiteString>(ms2_filters_str);
         }
       else
         {
-          msp_ms2FilterSuiteString =
-            std::make_shared<pappso::FilterSuiteString>(
-              "chargeDeconvolution|0.02dalton mzExclusion|0.01dalton");
+          msp_ms2FilterSuiteString = std::make_shared<pappso::FilterSuiteString>(
+            "chargeDeconvolution|0.02dalton mzExclusion|0.01dalton");
         }
     }
   else
     {
-      throw pappso::PappsoException(
-        QObject::tr("Error reading %1 X!Tandem preset file :\n %2")
-          .arg(tandem_preset_file)
-          .arg(preset_handler.errorString()));
+      throw pappso::PappsoException(QObject::tr("Error reading %1 X!Tandem preset file :\n %2")
+                                      .arg(tandem_preset_file)
+                                      .arg(preset_handler.errorString()));
     }
 }
 
@@ -343,12 +325,9 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
   // create new tandem input file based on new mzXML file
 
 
-  QString mzxml_data_file_name =
-    mpa_temporaryDirectory->filePath("msdata.mzxml");
-  QString wrapped_tandem_input =
-    mpa_temporaryDirectory->filePath("input_tandem.xml");
-  QString wrapped_tandem_output =
-    mpa_temporaryDirectory->filePath("output_tandem.xml");
+  QString mzxml_data_file_name  = mpa_temporaryDirectory->filePath("msdata.mzxml");
+  QString wrapped_tandem_input  = mpa_temporaryDirectory->filePath("input_tandem.xml");
+  QString wrapped_tandem_output = mpa_temporaryDirectory->filePath("output_tandem.xml");
 
   WrapTandemInput wrap_tandem_input(
     mzxml_data_file_name, wrapped_tandem_input, wrapped_tandem_output);
@@ -359,19 +338,15 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
     }
   else
     {
-      throw pappso::PappsoException(
-        QObject::tr("Error reading %1 X!Tandem input file :\n %2")
-          .arg(tandem_input_file)
-          .arg(wrap_tandem_input.errorString()));
+      throw pappso::PappsoException(QObject::tr("Error reading %1 X!Tandem input file :\n %2")
+                                      .arg(tandem_input_file)
+                                      .arg(wrap_tandem_input.errorString()));
     }
 
 
-  if(m_tandemBinary.endsWith("tandemng") ||
-     m_tandemBinary.endsWith("tandemng.exe") ||
-     m_tandemBinary.endsWith("tandemng2015") ||
-     m_tandemBinary.endsWith("tandemng2015.exe") ||
-     m_tandemBinary.endsWith("tandemng2015p") ||
-     m_tandemBinary.endsWith("tandemng2015p.exe"))
+  if(m_tandemBinary.endsWith("tandemng") || m_tandemBinary.endsWith("tandemng.exe") ||
+     m_tandemBinary.endsWith("tandemng2015") || m_tandemBinary.endsWith("tandemng2015.exe") ||
+     m_tandemBinary.endsWith("tandemng2015p") || m_tandemBinary.endsWith("tandemng2015p.exe"))
     {
       // no wrapper
       //  launch tandem on original file
@@ -411,10 +386,8 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
 
 
       // convert to mzXML
-      QString original_msdata_file_name =
-        wrap_tandem_input.getOriginalMsDataFileName();
-      if(convertOrginalMsData2mzXmlData(original_msdata_file_name,
-                                        mzxml_data_file_name))
+      QString original_msdata_file_name = wrap_tandem_input.getOriginalMsDataFileName();
+      if(convertOrginalMsData2mzXmlData(original_msdata_file_name, mzxml_data_file_name))
         {
 
 
@@ -422,10 +395,9 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
           runTandem(wrapped_tandem_input);
 
           // rewrite tandem result file
-          writeFinalTandemOutput(
-            wrapped_tandem_output,
-            wrap_tandem_input.getOriginalTandemOutputFileName(),
-            original_msdata_file_name);
+          writeFinalTandemOutput(wrapped_tandem_output,
+                                 wrap_tandem_input.getOriginalTandemOutputFileName(),
+                                 original_msdata_file_name);
         }
       else
         {
@@ -436,8 +408,7 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
 }
 
 bool
-TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
-                                                 const QString &target)
+TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin, const QString &target)
 {
   qDebug();
   pappso::MsFileAccessor origin_access(origin, "runa1");
@@ -447,8 +418,7 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
   m_mzFormat = origin_access.getFileFormat();
   if(m_mzFormat == Enums::MsDataFormat::unknown)
     {
-      throw pappso::PappsoException(
-        QObject::tr("%1 file format not known").arg(origin));
+      throw pappso::PappsoException(QObject::tr("%1 file format not known").arg(origin));
     }
 
   if(origin_access.getFileFormat() == Enums::MsDataFormat::brukerTims)
@@ -459,11 +429,9 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
   if((origin_access.getFileFormat() == Enums::MsDataFormat::mzML) ||
      (origin_access.getFileFormat() == Enums::MsDataFormat::brukerTims))
     {
-      mp_monitor->setStatus(
-        QObject::tr("Converting %1 to mzXML %2").arg(origin).arg(target));
+      mp_monitor->setStatus(QObject::tr("Converting %1 to mzXML %2").arg(origin).arg(target));
       pappso::MsRunReaderSPtr p_reader;
-      p_reader =
-        origin_access.msRunReaderSPtr(origin_access.getMsRunIds().front());
+      p_reader = origin_access.msRunReaderSPtr(origin_access.getMsRunIds().front());
 
       pappso::TimsMsRunReaderMs2 *tims2_reader =
         dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
@@ -489,8 +457,7 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
           QElapsedTimer timer;
           m_conversionTime = 0;
           timer.start();
-          p_mzxml_output = new pappso::MzxmlOutput(
-            *mp_monitor, QTextStream(&output_file).device());
+          p_mzxml_output = new pappso::MzxmlOutput(*mp_monitor, QTextStream(&output_file).device());
 
           p_mzxml_output->maskMs1(true);
 
@@ -503,14 +470,13 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
           delete p_mzxml_output;
           m_conversionTime = timer.elapsed();
 
-          mp_monitor->setStatus(QObject::tr("Conversion finished in %1 seconds")
-                                  .arg(m_conversionTime / 1000));
+          mp_monitor->setStatus(
+            QObject::tr("Conversion finished in %1 seconds").arg(m_conversionTime / 1000));
         }
       else
         {
           throw pappso::PappsoException(
-            QObject::tr("unable to write into %1 mzXML output file")
-              .arg(target));
+            QObject::tr("unable to write into %1 mzXML output file").arg(target));
         }
 
       qDebug();
@@ -524,8 +490,7 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
 }
 
 void
-TandemWrapperRun::run(UiMonitorInterface &monitor,
-                      const QString &tandem_input_file)
+TandemWrapperRun::run(UiMonitorInterface &monitor, const QString &tandem_input_file)
 {
   mp_monitor = &monitor;
 
@@ -538,8 +503,7 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
   if(mp_monitor->shouldIstop())
     {
       throw pappso::ExceptionInterrupted(
-        QObject::tr("X!Tandem stopped by the user processing on file %1")
-          .arg(tandem_input_file));
+        QObject::tr("X!Tandem stopped by the user processing on file %1").arg(tandem_input_file));
     }
   m_xtProcess = new QProcess();
   QStringList arguments;
@@ -568,8 +532,7 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
 
   if(!m_xtProcess->waitForStarted())
     {
-      throw pappso::PappsoException(
-        QObject::tr("X!Tandem process failed to start"));
+      throw pappso::PappsoException(QObject::tr("X!Tandem process failed to start"));
     }
 
   qDebug() << m_tandemBinary << " " << m_xtProcess->arguments();
@@ -595,8 +558,7 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
     {
       // != QProcess::NormalExit
       throw pappso::PappsoException(
-        QObject::tr("error executing X!Tandem Status != 0 : %1")
-          .arg(m_tandemBinary));
+        QObject::tr("error executing X!Tandem Status != 0 : %1").arg(m_tandemBinary));
     }
   m_xtProcess = nullptr;
 }
