@@ -30,6 +30,7 @@
 #include <QDebug>
 #include <QFile>
 #include <QTextStream>
+#include <QJsonArray>
 
 
 /////////////////////// Local includes
@@ -158,6 +159,10 @@ Utils::roundToDecimal32bitsAsLongLongInt(pappso::pappso_double input)
 }
 
 
+// I think this is where the programs that I created for Win11 using MXE
+// crashed upon opening a mzML file. The crash occurred in pwizlite, but
+// my guess is that this is the function where we set the locale that makes
+// the program crash. Just to keep that in mind. Filippo Rusconi 20251209.
 std::string
 Utils::toUtf8StandardString(const QString &text)
 {
@@ -192,7 +197,7 @@ Utils::toUtf8StandardString(const QString &text)
       // std::locale::global(std::locale("C")); // set locale to default locale
       std::setlocale(LC_ALL, env_backup.c_str());
 #else // Set back the locale to the backed-up one.
-      std::locale::global(std::locale(""));  // sets locale according to OS environment
+      std::locale::global(std::locale("")); // sets locale according to OS environment
 #endif
     }
   catch(std::exception &error)
@@ -230,6 +235,29 @@ Utils::writeToFile(const QString &text, const QString &file_name)
   return false;
 }
 
+// Typically useful to debug bins...
+bool
+Utils::writeToFile(const std::vector<double> &data, int decimals, const QString &file_name)
+{
+  QFile file(file_name);
+
+  if(file.open(QFile::WriteOnly | QFile::Append))
+    {
+      file.open(QIODevice::WriteOnly);
+
+      QTextStream fileStream(&file);
+
+      for(auto &&value : data)
+        fileStream << QString("%1\n").arg(value, 0, 'f', decimals);
+
+      fileStream.flush();
+      file.close();
+
+      return true;
+    }
+
+  return false;
+}
 
 bool
 Utils::appendToFile(const QString &text, const QString &file_name)
@@ -742,4 +770,16 @@ Utils::translateAaModificationFromUnimod(const QString &unimod_accession)
   return nullptr;
 }
 
+
+QJsonArray
+Utils::toJson(const std::vector<double> &myVec)
+{
+  QJsonArray result;
+  for(auto i = myVec.begin(); i != myVec.end(); i++)
+    {
+      result.push_back((*i));
+    }
+  return result;
+}
+
 } // namespace pappso
