@@ -78,6 +78,7 @@ class PMSPP_LIB_DECL Utils
   static std::string toUtf8StandardString(const QString &text);
 
   static bool writeToFile(const QString &text, const QString &file_name);
+  static bool writeToFile(const std::vector<double> &data, int decimals, const QString &file_name);
   static bool appendToFile(const QString &text, const QString &file_name);
   static std::size_t extractScanNumberFromMzmlNativeId(const QString &spectrum_native_id);
 
@@ -139,11 +140,16 @@ class PMSPP_LIB_DECL Utils
   static QString toString(Enums::PeptideIon m_ionType);
 
 
-  static AaModificationP
-  guessAaModificationPbyMonoisotopicMassDelta(Enums::AminoAcidChar aa, pappso_double mass);
+  static AaModificationP guessAaModificationPbyMonoisotopicMassDelta(Enums::AminoAcidChar aa,
+                                                                     pappso_double mass);
 
 
   static AaModificationP translateAaModificationFromUnimod(const QString &unimod_accession);
+
+
+  /** @brief convert vector of double into json array
+   */
+  static QJsonArray toJson(const std::vector<double> &myVec);
 };
 
 } // namespace pappso
