@@ -28,6 +28,7 @@
 #include "timsdata.h"
 #include "pappsomspp/core/exception/exceptionnotfound.h"
 #include "pappsomspp/core/exception/exceptioninterrupted.h"
+#include "pappsomspp/core/exception/exceptionnotrecognized.h"
 #include "pappsomspp/core/processing/combiners/tracepluscombiner.h"
 #include <QDebug>
 #include <QSqlError>
@@ -51,15 +52,16 @@ TimsData::TimsData(QDir timsDataDirectory) : m_timsDataDirectory(timsDataDirecto
   if(!m_timsDataDirectory.exists())
     {
       qDebug();
-      throw PappsoException(QObject::tr("ERROR TIMS data directory %1 not found")
-                              .arg(m_timsDataDirectory.absolutePath()));
+      throw ExceptionNotRecognized(QObject::tr("ERROR TIMS data directory %1 not found")
+                                     .arg(m_timsDataDirectory.absolutePath()));
     }
 
   if(!QFileInfo(m_timsDataDirectory.absoluteFilePath("analysis.tdf")).exists())
     {
 
-      throw PappsoException(QObject::tr("ERROR TIMS data directory, %1 sqlite file not found")
-                              .arg(m_timsDataDirectory.absoluteFilePath("analysis.tdf")));
+      throw ExceptionNotRecognized(
+        QObject::tr("ERROR TIMS data directory, %1 sqlite file not found")
+          .arg(m_timsDataDirectory.absoluteFilePath("analysis.tdf")));
     }
 
   // Open the database
