@@ -117,8 +117,7 @@ std::size_t
 TimsFrameBase::getScanPeakCount(std::size_t scanNum) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to get number of peaks in TimsFrameBase for scan number %1")
+    QObject::tr("ERROR unable to get number of peaks in TimsFrameBase for scan number %1")
       .arg(scanNum));
 }
 
@@ -132,8 +131,7 @@ MassSpectrumSPtr
 TimsFrameBase::getMassSpectrumSPtr(std::size_t scanNum) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to getMassSpectrumSPtr in TimsFrameBase for scan number %1")
+    QObject::tr("ERROR unable to getMassSpectrumSPtr in TimsFrameBase for scan number %1")
       .arg(scanNum));
 }
 
@@ -146,14 +144,12 @@ TimsFrameBase::getMassSpectrumCstSPtr(std::size_t scanNum) const
   return getMassSpectrumSPtr(scanNum);
 }
 Trace
-TimsFrameBase::cumulateScansToTrace(std::size_t scanNumBegin,
-                                    std::size_t scanNumEnd) const
+TimsFrameBase::cumulateScansToTrace(std::size_t scanNumBegin, std::size_t scanNumEnd) const
 {
-  throw PappsoException(
-    QObject::tr("ERROR unable to cumulateScanToTrace in TimsFrameBase for scan "
-                "number begin %1 end %2")
-      .arg(scanNumBegin)
-      .arg(scanNumEnd));
+  throw PappsoException(QObject::tr("ERROR unable to cumulateScanToTrace in TimsFrameBase for scan "
+                                    "number begin %1 end %2")
+                          .arg(scanNumBegin)
+                          .arg(scanNumEnd));
 }
 
 Trace
@@ -164,10 +160,8 @@ TimsFrameBase::combineScansToTraceWithDowngradedMzResolution(
   quint32 &minimum_tof_index_out [[maybe_unused]],
   quint32 &maximum_tof_index_out [[maybe_unused]]) const
 {
-  throw PappsoException(QObject::tr("Non implemented function %1 %2 %3")
-                          .arg(__FILE__)
-                          .arg(__FUNCTION__)
-                          .arg(__LINE__));
+  throw PappsoException(
+    QObject::tr("Non implemented function %1 %2 %3").arg(__FILE__).arg(__FUNCTION__).arg(__LINE__));
 }
 
 Trace
@@ -180,55 +174,45 @@ TimsFrameBase::combineScansToTraceWithDowngradedMzResolution2(
   quint32 &mz_minimum_index_out [[maybe_unused]],
   quint32 &mz_maximum_index_out [[maybe_unused]]) const
 {
-  throw PappsoException(QObject::tr("Non implemented function %1 %2 %3")
-                          .arg(__FILE__)
-                          .arg(__FUNCTION__)
-                          .arg(__LINE__));
+  throw PappsoException(
+    QObject::tr("Non implemented function %1 %2 %3").arg(__FILE__).arg(__FUNCTION__).arg(__LINE__));
 }
 
 Trace
 TimsFrameBase::getMobilityScan(std::size_t scanNum [[maybe_unused]],
-                               std::size_t mz_index_merge_window
-                               [[maybe_unused]],
+                               std::size_t mz_index_merge_window [[maybe_unused]],
                                double mz_range_begin [[maybe_unused]],
                                double mz_range_end [[maybe_unused]],
                                quint32 &mz_minimum_index_out [[maybe_unused]],
-                               quint32 &mz_maximum_index_out
-                               [[maybe_unused]]) const
+                               quint32 &mz_maximum_index_out [[maybe_unused]]) const
 {
-  throw PappsoException(QObject::tr("Non implemented function %1 %2 %3")
-                          .arg(__FILE__)
-                          .arg(__FUNCTION__)
-                          .arg(__LINE__));
+  throw PappsoException(
+    QObject::tr("Non implemented function %1 %2 %3").arg(__FILE__).arg(__FUNCTION__).arg(__LINE__));
 }
 
 void
-TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum
-                                                  [[maybe_unused]],
+TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum [[maybe_unused]],
                                                   std::size_t scanNumBegin,
                                                   std::size_t scanNumEnd) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
-      "number begin %1 end %2")
+    QObject::tr("ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
+                "number begin %1 end %2")
       .arg(scanNumBegin)
       .arg(scanNumEnd));
 }
 
 
 void
-TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum
-                                                  [[maybe_unused]],
+TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum [[maybe_unused]],
                                                   std::size_t scanNumBegin,
                                                   std::size_t scanNumEnd,
                                                   quint32 tof_index_begin,
                                                   quint32 tof_index_end) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
-      "number begin %1 end %2, tof index begin %3, tof index end %4")
+    QObject::tr("ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
+                "number begin %1 end %2, tof index begin %3, tof index end %4")
       .arg(scanNumBegin)
       .arg(scanNumEnd)
       .arg(tof_index_begin)
@@ -239,9 +223,8 @@ quint64
 TimsFrameBase::cumulateScanIntensities(std::size_t scanNum) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to cumulateSingleScanIntensities in TimsFrameBase for scan "
-      "number %1.")
+    QObject::tr("ERROR unable to cumulateSingleScanIntensities in TimsFrameBase for scan "
+                "number %1.")
       .arg(scanNum));
 
   return 0;
@@ -249,13 +232,11 @@ TimsFrameBase::cumulateScanIntensities(std::size_t scanNum) const
 
 
 quint64
-TimsFrameBase::cumulateScanRangeIntensities(std::size_t scanNumBegin,
-                                            std::size_t scanNumEnd) const
+TimsFrameBase::cumulateScanRangeIntensities(std::size_t scanNumBegin, std::size_t scanNumEnd) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
-      "number begin %1 end %2")
+    QObject::tr("ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
+                "number begin %1 end %2")
       .arg(scanNumBegin)
       .arg(scanNumEnd));
 
@@ -310,8 +291,8 @@ TimsFrameBase::setTimsCalibration(int tims_model_type,
 {
   if(tims_model_type != 2)
     {
-      throw pappso::PappsoException(QObject::tr(
-        "ERROR in TimsFrame::setTimsCalibration tims_model_type != 2"));
+      throw pappso::PappsoException(
+        QObject::tr("ERROR in TimsFrame::setTimsCalibration tims_model_type != 2"));
     }
   m_timsDvStart = C2; // C2 from TimsCalibration
   m_timsTtrans  = C4; // C4 from TimsCalibration
@@ -322,15 +303,13 @@ TimsFrameBase::setTimsCalibration(int tims_model_type,
   m_timsC7      = C7;
 
 
-  m_timsSlope =
-    (C3 - m_timsDvStart) / C1; //  //C3 from TimsCalibration // C2 from
-                               //  TimsCalibration // C1 from TimsCalibration
+  m_timsSlope = (C3 - m_timsDvStart) / C1; //  //C3 from TimsCalibration // C2 from
+                                           //  TimsCalibration // C1 from TimsCalibration
 }
 double
 TimsFrameBase::getVoltageTransformation(std::size_t scanNum) const
 {
-  double v = m_timsDvStart +
-             m_timsSlope * ((double)scanNum - m_timsTtrans - m_timsNdelay);
+  double v = m_timsDvStart + m_timsSlope * ((double)scanNum - m_timsTtrans - m_timsNdelay);
 
   if(v < m_timsVmin)
     {
@@ -355,8 +334,7 @@ TimsFrameBase::getVoltageTransformation(std::size_t scanNum) const
 double
 TimsFrameBase::getDriftTimeInMilliseconds(std::size_t scanNum) const
 {
-  return (m_acqDurationInMilliseconds / (double)m_scanCount) *
-         ((double)scanNum);
+  return (m_acqDurationInMilliseconds / (double)m_scanCount) * ((double)scanNum);
 }
 
 double
@@ -381,8 +359,7 @@ TimsFrameBase::getScanIndexFromOneOverK0(double one_over_k0) const
 bool
 TimsFrameBase::hasSameCalibrationData(const TimsFrameBase &other) const
 {
-  if((m_timsDvStart == other.m_timsDvStart) &&
-     (m_timsTtrans == other.m_timsTtrans) &&
+  if((m_timsDvStart == other.m_timsDvStart) && (m_timsTtrans == other.m_timsTtrans) &&
      (m_timsNdelay == other.m_timsNdelay) && (m_timsVmin == other.m_timsVmin) &&
      (m_timsVmax == other.m_timsVmax) && (m_timsC6 == other.m_timsC6) &&
      (m_timsC7 == other.m_timsC7) && (m_timsSlope == other.m_timsSlope))
@@ -394,24 +371,22 @@ TimsFrameBase::hasSameCalibrationData(const TimsFrameBase &other) const
 
 
 pappso::Trace
-TimsFrameBase::getTraceFromTofIndexIntensityMap(
-  TimsDataFastMap &accumulated_scans) const
+TimsFrameBase::getTraceFromTofIndexIntensityMap(TimsDataFastMap &accumulated_scans) const
 {
   qDebug();
   // qDebug();
   // add flanking peaks
   pappso::Trace local_trace;
 
-  MzCalibrationInterface *mz_calibration_p =
-    getMzCalibrationInterfaceSPtr().get();
+  MzCalibrationInterface *mz_calibration_p = getMzCalibrationInterfaceSPtr().get();
 
 
   DataPoint element;
   for(quint32 tof_index : accumulated_scans.getTofIndexList())
     {
       // intensity normalization
-      element.y = ((double)accumulated_scans.readIntensity(tof_index)) * 100.0 /
-                  m_acqDurationInMilliseconds;
+      element.y =
+        ((double)accumulated_scans.readIntensity(tof_index)) * 100.0 / m_acqDurationInMilliseconds;
 
       // mz calibration
       element.x = mz_calibration_p->getMzFromTofIndex(tof_index);
@@ -431,28 +406,25 @@ TimsFrameBase::getMzCalibrationInterfaceSPtr() const
   if(msp_mzCalibration == nullptr)
     {
 
-      throw pappso::PappsoException(
-        QObject::tr("ERROR in %1, %2, %3 msp_mzCalibration is null")
-          .arg(__FILE__)
-          .arg(__FUNCTION__)
-          .arg(__LINE__));
+      throw pappso::PappsoException(QObject::tr("ERROR in %1, %2, %3 msp_mzCalibration is null")
+                                      .arg(__FILE__)
+                                      .arg(__FUNCTION__)
+                                      .arg(__LINE__));
     }
   return msp_mzCalibration;
 }
 
 void
-TimsFrameBase::setMzCalibrationInterfaceSPtr(
-  MzCalibrationInterfaceSPtr mzCalibration)
+TimsFrameBase::setMzCalibrationInterfaceSPtr(MzCalibrationInterfaceSPtr mzCalibration)
 {
 
   if(mzCalibration == nullptr)
     {
 
-      throw pappso::PappsoException(
-        QObject::tr("ERROR in %1, %2, %3 msp_mzCalibration is null")
-          .arg(__FILE__)
-          .arg(__FUNCTION__)
-          .arg(__LINE__));
+      throw pappso::PappsoException(QObject::tr("ERROR in %1, %2, %3 msp_mzCalibration is null")
+                                      .arg(__FILE__)
+                                      .arg(__FUNCTION__)
+                                      .arg(__LINE__));
     }
   msp_mzCalibration = mzCalibration;
 }
@@ -466,7 +438,7 @@ TimsFrameBase::getMaximumRawMassIndex() const
     {
       qDebug() << "m_scanNumber=" << m_scanCount << " i=" << i;
       std::vector<quint32> index_list = getScanTofIndexList(i);
-      auto it = std::max_element(index_list.begin(), index_list.end());
+      auto it                         = std::max_element(index_list.begin(), index_list.end());
       if(it != index_list.end())
         {
           max_value = std::max(max_value, *it);
@@ -479,8 +451,7 @@ std::vector<quint32>
 TimsFrameBase::getScanTofIndexList(std::size_t scanNum) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to getScanIndexList in TimsFrameBase for scan number %1")
+    QObject::tr("ERROR unable to getScanIndexList in TimsFrameBase for scan number %1")
       .arg(scanNum));
 }
 
@@ -489,18 +460,16 @@ std::vector<quint32>
 TimsFrameBase::getScanIntensityList(std::size_t scanNum) const
 {
   throw PappsoException(
-    QObject::tr(
-      "ERROR unable to getScanIntensities in TimsFrameBase for scan number %1")
+    QObject::tr("ERROR unable to getScanIntensities in TimsFrameBase for scan number %1")
       .arg(scanNum));
 }
 
 Trace
-TimsFrameBase::getIonMobilityTraceByTofIndexRange(
-  std::size_t tof_index_begin,
-  std::size_t tof_index_end,
-  Enums::XicExtractMethod method,
-  std::size_t scan_index_begin,
-  std::size_t scan_index_end) const
+TimsFrameBase::getIonMobilityTraceByTofIndexRange(std::size_t tof_index_begin,
+                                                  std::size_t tof_index_end,
+                                                  Enums::XicExtractMethod method,
+                                                  std::size_t scan_index_begin,
+                                                  std::size_t scan_index_end) const
 {
   Trace im_trace;
   DataPoint data_point;
@@ -512,15 +481,14 @@ TimsFrameBase::getIonMobilityTraceByTofIndexRange(
       data_point.y = 0;
       qDebug() << "m_scanNumber=" << m_scanCount << " i=" << i;
       std::vector<quint32> index_list = getScanTofIndexList(i);
-      auto it_lower                   = std::find_if(index_list.begin(),
-                                   index_list.end(),
-                                   [tof_index_begin](quint32 to_compare) {
-                                     if(to_compare < tof_index_begin)
-                                       {
-                                         return false;
-                                       }
-                                     return true;
-                                   });
+      auto it_lower =
+        std::find_if(index_list.begin(), index_list.end(), [tof_index_begin](quint32 to_compare) {
+          if(to_compare < tof_index_begin)
+            {
+              return false;
+            }
+          return true;
+        });
 
 
       if(it_lower == index_list.end())
@@ -530,15 +498,14 @@ TimsFrameBase::getIonMobilityTraceByTofIndexRange(
         {
 
 
-          auto it_upper                       = std::find_if(index_list.begin(),
-                                       index_list.end(),
-                                       [tof_index_end](quint32 to_compare) {
-                                         if(tof_index_end >= to_compare)
-                                           {
-                                             return false;
-                                           }
-                                         return true;
-                                       });
+          auto it_upper =
+            std::find_if(index_list.begin(), index_list.end(), [tof_index_end](quint32 to_compare) {
+              if(tof_index_end >= to_compare)
+                {
+                  return false;
+                }
+              return true;
+            });
           std::vector<quint32> intensity_list = getScanIntensityList(i);
           for(int j = std::distance(index_list.begin(), it_lower);
               j < std::distance(index_list.begin(), it_upper);
@@ -550,8 +517,7 @@ TimsFrameBase::getIonMobilityTraceByTofIndexRange(
                 }
               else
                 {
-                  data_point.y =
-                    std::max((double)intensity_list[j], data_point.y);
+                  data_point.y = std::max((double)intensity_list[j], data_point.y);
                 }
             }
         }
@@ -577,7 +543,7 @@ TimsFrameBase::downgradeResolutionOfTofIndexIntensityPairList(
   for(auto &pair_mz_intensity : rawSpectrum)
     {
       quint32 mzkey = (pair_mz_intensity.tof_index / mzindex_merge_window);
-      mzkey = (mzkey * mzindex_merge_window) + (mzindex_merge_window / 2);
+      mzkey         = (mzkey * mzindex_merge_window) + (mzindex_merge_window / 2);
 
       if(current_point.tof_index != mzkey)
         {
