@@ -41,8 +41,7 @@ namespace pappso
 {
 
 
-BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent)
-  : BasePlotWidget(parent)
+BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent) : BasePlotWidget(parent)
 {
   // We can afford to call createAllAncillaryItems() in this derived class
   // because all the items will have been created *before* the addition of plots
@@ -186,8 +185,7 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
   // qDebug();
 
   if(!color.isValid())
-    throw PappsoException(
-      QString("The color to be used for the plot graph is invalid."));
+    throw PappsoException(QString("The color to be used for the plot graph is invalid."));
 
   // This seems to be unpleasant.
   // setFocus();
@@ -254,12 +252,10 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
   // Connect the signal of selection change so that we can re-emit it for the
   // widget that is using *this widget.
 
-  connect(graph_p,
-          static_cast<void (QCPAbstractPlottable::*)(bool)>(
-            &QCPAbstractPlottable::selectionChanged),
-          [this, graph_p]() {
-            emit plottableSelectionChangedSignal(graph_p, graph_p->selected());
-          });
+  connect(
+    graph_p,
+    static_cast<void (QCPAbstractPlottable::*)(bool)>(&QCPAbstractPlottable::selectionChanged),
+    [this, graph_p]() { emit plottableSelectionChangedSignal(graph_p, graph_p->selected()); });
 
   // Rescaling the axes is actually unpleasant if there are more than one
   // graph in the plot widget and that we are adding one. So only, rescale if
@@ -286,9 +282,7 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
 
 */
 bool
-BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index,
-                                                     double key,
-                                                     QCPRange &range)
+BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index, double key, QCPRange &range)
 {
 
   // Given a key double value, we want to know what is the range that will
@@ -308,8 +302,7 @@ BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index,
   // QCPDataContainer< DataType > is a Class Template. So in this context,
   // DataType is QCPGraphData.
   // QCPGraphData is the data point, that is the (key,value) pair.
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
-    theGraph->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = theGraph->data();
 
   QCPDataRange dataRange = graph_data_container_p->dataRange();
 
@@ -355,11 +348,8 @@ BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index,
       // Finally the generic case where the user point to any point *in* the
       // graph.
 
-      range.lower =
-        graph_data_container_p->findBegin(key, /*expandedRange*/ true)->key;
-      range.upper =
-        std::prev(graph_data_container_p->findEnd(key, /*expandedRange*/ true))
-          ->key;
+      range.lower = graph_data_container_p->findBegin(key, /*expandedRange*/ true)->key;
+      range.upper = std::prev(graph_data_container_p->findEnd(key, /*expandedRange*/ true))->key;
 
       return true;
     }
@@ -378,8 +368,7 @@ BaseTracePlotWidget::getValuesX(int graph_index) const
   if(graph_p == nullptr)
     qFatal("Programming error.");
 
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
-    graph_p->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
 
   // Iterate in the keys
   auto beginIt = graph_data_container_p->begin();
@@ -402,8 +391,7 @@ BaseTracePlotWidget::getValuesY(int graph_index) const
   if(graph_p == nullptr)
     qFatal("Programming error.");
 
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
-    graph_p->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
 
   // Iterate in the values
   auto beginIt = graph_data_container_p->begin();
@@ -417,8 +405,7 @@ BaseTracePlotWidget::getValuesY(int graph_index) const
 
 
 QCPRange
-BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p,
-                                             bool &ok)
+BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p, bool &ok)
 {
 
   // The X axis range is set. But we want to find for that X axis range the
@@ -453,8 +440,7 @@ BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p,
         {
           QCPGraph *plottable_p = graph(iter);
 
-          QCPRange value_range =
-            plottable_p->getValueRange(ok, QCP::SignDomain::sdBoth, key_range);
+          QCPRange value_range = plottable_p->getValueRange(ok, QCP::SignDomain::sdBoth, key_range);
 
           if(ok)
             found_range = true;
@@ -527,10 +513,9 @@ BaseTracePlotWidget::getYatX(double x, int index)
 
 
 void
-BaseTracePlotWidget::axisDoubleClickHandler(
-  QCPAxis *axis,
-  [[maybe_unused]] QCPAxis::SelectablePart part,
-  QMouseEvent *event)
+BaseTracePlotWidget::axisDoubleClickHandler(QCPAxis *axis,
+                                            [[maybe_unused]] QCPAxis::SelectablePart part,
+                                            QMouseEvent *event)
 {
   // qDebug();
 
@@ -617,8 +602,7 @@ BaseTracePlotWidget::axisRescale()
       // We are changing the range of the X axis.
 
       // What is the x delta ?
-      double xDelta =
-        m_context.m_currentDragPoint.x() - m_context.m_startDragPoint.x();
+      double xDelta = m_context.m_currentDragPoint.x() - m_context.m_startDragPoint.x();
 
       // If xDelta is < 0, the  we were dragging from right to left, we are
       // compressing the view on the x axis, by adding new data to the right
@@ -678,8 +662,7 @@ BaseTracePlotWidget::axisRescale()
       // We are changing the range of the Y axis.
 
       // What is the y delta ?
-      double yDelta =
-        m_context.m_currentDragPoint.y() - m_context.m_startDragPoint.y();
+      double yDelta = m_context.m_currentDragPoint.y() - m_context.m_startDragPoint.y();
 
       // See above for an explanation of the computation.
 
@@ -727,16 +710,14 @@ BaseTracePlotWidget::axisReframe()
   // xAxis->setRange(sorted_start_drag_point_x,
   // sorted_start_drag_point_x + fabs(m_context.m_xDelta));
 
-  xAxis->setRange(
-    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
+  xAxis->setRange(QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // Note that the y axis should be rescaled from current lower value to new
   // upper value matching the y-axis position of the cursor when the mouse
   // button was released.
 
   yAxis->setRange(xAxis->range().lower,
-                  std::max<double>(m_context.m_yRegionRangeStart,
-                                   m_context.m_yRegionRangeEnd));
+                  std::max<double>(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
 
   // qDebug() << "xaxis:" << xAxis->range().lower << "-" <<
   // xAxis->range().upper
@@ -773,8 +754,7 @@ BaseTracePlotWidget::axisZoom()
   // value. Simply craft a QCPRange that will swap the values if lower is not
   // < than upper QCustomPlot calls this normalization).
 
-  xAxis->setRange(
-    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
+  xAxis->setRange(QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // If the shift modifier key is pressed, then the user want the y axis
   // to be full scale.
@@ -788,8 +768,7 @@ BaseTracePlotWidget::axisZoom()
       yAxis->setRange(value_range);
     }
   else
-    yAxis->setRange(
-      QCPRange(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
+    yAxis->setRange(QCPRange(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
 
   updateContextXandYAxisRanges();
 
@@ -871,8 +850,7 @@ BaseTracePlotWidget::toTrace(const QCPGraph *graph_p) const
 
   pappso::Trace trace;
 
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
-    graph_p->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
 
   // Iterate in the keys
   auto beginIt = graph_data_container_p->begin();
@@ -898,8 +876,7 @@ BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, int index) const
 
 
 pappso::Trace
-BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range,
-                             const QCPGraph *graph_p) const
+BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, const QCPGraph *graph_p) const
 {
 
   // Make a Trace with the data in the range.
