@@ -327,6 +327,10 @@ MassSpecTracePlotWidget::deconvolute()
   span encompasses two \e consecutive mass peaks of a given charge state
   envelope.
 
+  The z charge that is computed is for the first peak that was clicked
+  in the trace plot, and thus the Mr value that is returned is calculated
+  from the m/z value under the peak that was clicked first.
+
   Set m_lastMz, m_lastZ and m_lastMass.
 
   \return true if the deconvolution could be performed, false otherwise.
@@ -342,7 +346,7 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   // That parameter defaults to 1, that is the two peaks are immediately
   // consecutive, that is, there is only one interval.
 
-  qDebug() << "The span is:" << span;
+  // qDebug() << "The span is:" << span;
 
   // The m_context ranges are inherently sorted. This is not something that
   // is favorable to us because we need to know what is the direction of the
@@ -355,7 +359,7 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   double startMz = m_context.m_xRegionRangeStart;
   double curMz   = m_context.m_xRegionRangeEnd;
 
-  qDebug() << "startMz:" << startMz << "curMz:" << curMz;
+  // qDebug() << "startMz:" << startMz << "curMz:" << curMz;
 
   if(startMz == curMz)
     {
@@ -364,7 +368,7 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
       m_context.m_lastTicIntensity = qQNaN();
       m_context.m_lastMr           = qQNaN();
 
-      qDebug() << "Start and Cur are the same, no deconvolution possible.";
+      // qDebug() << "Start and Cur are the same, no deconvolution possible.";
       return false;
     }
 
@@ -420,7 +424,7 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   else
     m_context.m_lastZ = chargeIntPart;
 
-  qDebug() << "Initially computed m_lastZ as " << m_context.m_lastZ;
+  // qDebug() << "Initially computed m_lastZ as " << m_context.m_lastZ;
 
   // We know the that formula above computed the charge of the least charged
   // ion, that corresponds to the greater m/z value of the range: curMz.
@@ -431,28 +435,28 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
 
   if(static_cast<int>(m_context.m_dragDirections) & static_cast<int>(DragDirections::RIGHT_TO_LEFT))
     {
-      qDebug() << "Dragging from right to left, that is from higher m/z value.";
+      // qDebug() << "Dragging from right to left, that is from higher m/z value.";
       m_context.m_lastMz = curMz;
     }
   else if(static_cast<int>(m_context.m_dragDirections) &
           static_cast<int>(DragDirections::LEFT_TO_RIGHT))
     {
-      qDebug() << "Dragging from left to right, we need to report"
-               << "the mass for the left peak, that is for z+span and lower m/z value.";
+      // qDebug() << "Dragging from left to right, we need to report"
+      //          << "the mass for the left peak, that is for z+span and lower m/z value.";
       m_context.m_lastZ += span;
       m_context.m_lastMz = startMz;
     }
 
-  qDebug() << "Final m_lastZ is " << m_context.m_lastZ << "m/z: m_context.m_lastMz";
+  // qDebug() << "Final m_lastZ is " << m_context.m_lastZ << "m/z: m_context.m_lastMz";
 
   m_context.m_lastMr = (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
-  qDebug() << "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
-           << "curMz:" << QString("%1").arg(curMz, 0, 'f', 6)
-           << "m_lastMz (make computation for this startMz):"
-           << QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
-           << "m_lastZ:" << QString("%1").arg(m_context.m_lastZ)
-           << "m_lastMass:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6);
+  // qDebug() << "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
+  //          << "curMz:" << QString("%1").arg(curMz, 0, 'f', 6)
+  //          << "m_lastMz (make computation for this startMz):"
+  //          << QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
+  //          << "m_lastZ:" << QString("%1").arg(m_context.m_lastZ)
+  //          << "m_lastMass:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6);
 
   // The m_context was refreshed with the base class context in the calling
   // chain.
@@ -479,11 +483,16 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
 bool
 MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
 {
+  // The m_context ranges are inherently sorted. This is not something that
+  // is favorable to us because we need to know what is the direction of the
+  // drag. That should be configurable, but we can establish that by
+  // default, the z value will be calculated for the mass peak at which
+  // the mouse drag movement started.
 
   double startMz = m_context.m_xRegionRangeStart;
   double curMz   = m_context.m_xRegionRangeEnd;
 
-  qDebug() << "startMz:" << startMz << "curMz:" << curMz;
+  // qDebug() << "startMz:" << startMz << "curMz:" << curMz;
 
   if(startMz == curMz)
     {
@@ -495,10 +504,17 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
       return false;
     }
 
+  // After much discussion with people who perform mass data analysis for
+  // heavy isotope fully labelled analytes, it was decided that the Mr
+  // value thas is returned is for the peak from which the drag operation
+  // was performed. This is an analogous way of computing Mr as that used
+  // in the charge state envelope method.
+
+
   double chargeTemp = 1 / fabs(m_context.m_xDelta);
 
-  qDebug() << qSetRealNumberPrecision(6) << "curMz - startMz = " << fabs(curMz - startMz)
-           << "while m_context.m_xDelta = " << m_context.m_xDelta;
+  // qDebug() << qSetRealNumberPrecision(6) << "curMz - startMz = " << fabs(curMz - startMz)
+  //          << "while m_context.m_xDelta = " << m_context.m_xDelta;
 
   // Sanity check
   if(fabs(m_context.m_xDelta) != fabs(curMz - startMz))
@@ -548,13 +564,27 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
   // qDebug() << "Settled on m_lastZ: " << m_context.m_lastZ;
 
   // Now that we have the charge in the form of an int, we can compute the
-  // Mr of the lightest isotopic cluster peak (the one that has the lowest x
-  // value). That value is stored in m_xRangeLower.
+  // Mr of the isotopic cluster peak that was under the cursor when the
+  // mouse drag started.
 
-  // We need to sort the xRegionRange before being certain that lower is indeed
-  // the left value of the drag span.
+  // If we know the drag direction, we would automatically know what is the
+  // peak that was under the cursor when the mouse drag mouvement was initiated.
+  // This is because the curMz is inherently larger than startMz because
+  // m_context.m_xRegionRangeStart and m_context.m_xRegionRangeEnd are inherently
+  // sorted (start < end).
 
-  m_context.m_lastMz = std::min<double>(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd);
+  if(static_cast<int>(m_context.m_dragDirections) & static_cast<int>(DragDirections::RIGHT_TO_LEFT))
+    {
+      // qDebug() << "Dragging from right to left, that is from higher m/z value.";
+      m_context.m_lastMz = curMz;
+    }
+  else if(static_cast<int>(m_context.m_dragDirections) &
+          static_cast<int>(DragDirections::LEFT_TO_RIGHT))
+    {
+      // qDebug() << "Dragging from left to right, we need to report"
+      //          << "the mass for the left peak.";
+      m_context.m_lastMz = startMz;
+    }
 
   m_context.m_lastMr = (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
