@@ -55,7 +55,7 @@ TEST_CASE("Creating mass spectrum via TIMS XIC extraction from timsdata",
 {
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
-#if USEPAPPSOTREE == 1
+#if USE_PAPPSO_TREE == 1
 
   QString file_path_name;
 
@@ -195,7 +195,7 @@ TEST_CASE("Creating mass spectrum via TIMS XIC extraction from timsdata",
   std::cout << "The full mass spectrum for the acquisition:\n"
             << full_mass_spectrum_trace.toString().toStdString();
 
-#elif USEPAPPSOTREE == 1
+#elif USE_PAPPSO_TREE == 1
 
   std::cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
 
