@@ -142,10 +142,9 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     // Prepare the bins on the basis of the spectrum.
 
-    int decimal_places = 5;
-    pappso::PrecisionPtr precision_p =
-      pappso::PrecisionFactory::getDaltonInstance(0.05);
-    bool binSizeDivisor = 6;
+    int decimal_places               = 5;
+    pappso::PrecisionPtr precision_p = pappso::PrecisionFactory::getDaltonInstance(0.05);
+    bool binSizeDivisor              = 6;
 
     MzIntegrationParams mz_integration_params(610.02,
                                               611.97,
@@ -176,11 +175,15 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     mass_spectrum_combiner.combine(map_trace, mass_spectrum1);
 
+    // Because the bins are copied inside of map_trace as a first step
+    // when map_trace is empty (which it is), the size of map_trace
+    // is the size of the bins vector.
+    REQUIRE(map_trace.size() == mass_spectrum1.size() + mass_spectrum2.size() + 1);
+
     // std::cout << std::setprecision(10)
     //<< "First map item x: " << map_trace.begin()->first
     //<< " y: " << map_trace.begin()->second << std::endl;
 
-    REQUIRE(map_trace.size() == 20);
     REQUIRE(map_trace[610.02000] == 12963.5715942383);
     REQUIRE(map_trace[610.27000] == 54459.4762458801);
     REQUIRE(map_trace[610.97000] == 22105.9357604980);
@@ -189,7 +192,6 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     mass_spectrum_combiner.combine(map_trace, mass_spectrum2);
 
-    REQUIRE(map_trace.size() == 40);
     REQUIRE(map_trace[610.02000] == 12963.5715942383);
     REQUIRE(map_trace[610.27000] == 54459.4762458801);
     REQUIRE(map_trace[610.97000] == 22105.9357604980);
@@ -261,6 +263,10 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     REQUIRE(20 == data_point_vector.size());
 
+    std::cout << "Now ouputting the trace." << std::endl;
+    for(auto dp : data_point_vector)
+      std::cout << std::setprecision(10) << dp.x << " " << dp.y << std::endl;
+
     MassSpectrum mass_spectrum2(data_point_vector);
 
     REQUIRE(20 == mass_spectrum2.size());
@@ -268,12 +274,11 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     // Prepare the bins on the basis of the spectrum.
 
-    int decimal_places = 5;
-    pappso::PrecisionPtr precision_p =
-      pappso::PrecisionFactory::getDaltonInstance(0.05);
-    bool binSizeDivisor = 6;
+    int decimal_places               = 5;
+    pappso::PrecisionPtr precision_p = pappso::PrecisionFactory::getDaltonInstance(0.05);
+    bool binSizeDivisor              = 6;
 
-    MzIntegrationParams mz_integration_params(610.02,
+    MzIntegrationParams mz_integration_params(610.025,
                                               610.975,
                                               MzIntegrationParams::BinningType::ARBITRARY,
                                               precision_p,
@@ -281,13 +286,18 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
                                               decimal_places,
                                               true);
 
-    // Check that it does not compute bins, since BinningType::NONE.
-
     std::vector<double> bins = mz_integration_params.createBins();
-    REQUIRE(bins.size() == 21);
-    REQUIRE(bins[0] == 610.02000);
 
-    REQUIRE(bins.back() == 610.97000 + 0.05);
+    REQUIRE(bins.size() == 21);
+
+    std::cout << "Now ouputting the bins." << std::endl;
+    for(auto bin : bins)
+      std::cout << std::setprecision(10) << bin << std::endl;
+
+    REQUIRE(bins[0] == 610.02500);
+
+    // The last bin will be greater than the last m/z value 610.975
+    REQUIRE(bins.back() == 610.025 + (bins.size() -1) * 0.05);
 
     MassSpectrumPlusCombiner mass_spectrum_combiner(decimal_places);
     mass_spectrum_combiner.setBins(bins);
@@ -296,10 +306,16 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     mass_spectrum_combiner.combine(map_trace, mass_spectrum1);
 
-    REQUIRE(map_trace.size() == 20);
+    REQUIRE(map_trace.size() == bins.size());
+
+    std::cout << "Now ouputting the map_trace." << std::endl;
+    for(auto pair : map_trace)
+      std::cout << std::setprecision(10) << pair.first << " " << pair.second << std::endl;
   }
 }
 
 #endif
+// End of
+// #if !defined(__i386__)
 
 } // namespace pappso
