@@ -33,7 +33,7 @@
 #include <catch2/catch_test_macros.hpp>
 #include <QDebug>
 #include <QIODevice>
-#include <pappsomspp/processing/uimonitor/uimonitortextpercent.h>
+#include <pappsomspp/core/processing/uimonitor/uimonitortextpercent.h>
 #include <iostream>
 
 using namespace pappso;
